diff -pruN 0.14.1-3/CHANGELOG 0.15.0-0ubuntu1/CHANGELOG
--- 0.14.1-3/CHANGELOG	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/CHANGELOG	2020-04-24 03:22:14.000000000 +0000
@@ -1,3 +1,42 @@
+qtermwidget-0.15.0 / 2020-04-24
+===============================
+
+  * Bumped version to 0.15.0.
+  * Replaced Q_WS_MAC with Q_OS_MACOS for Qt5 compatibility.
+  * KPty: Don't conditionalize chownpty existence on HAVE_OPENPTY.
+  * cmake: set CMAKE_BUILD_WITH_INSTALL_NAME_DIR ON for macOS.
+  * Fixed the default font on macOS.
+  * pyqt: Fixes deprecation warning (CMP0002).
+  * Fixed the PyQt5 binding with Qt ≥ 5.11.
+  * Swap Qt's ControlModifier and MetaModifier on macOS.
+  * C++11 code updates.
+  * Use braced initializer list in returns.
+  * Fixed the memory access violation in TerminalDisplay's method `getCharacterPosition`.
+  * Completed the support for transient scrollbars.
+  * Added `saveHistory` to QTermWidget.
+  * Use vanilla Qt instead of patched one.
+  * Don't set the selection clipboard if it's unsupported.
+  * Announce truecolor support via COLORTERM.
+  * Fixed numpad handling and added entries for numpad 5.
+  * Allow to disable drawing line chars.
+  * Use QRectF for cursor drawing and fix artifacts in hidpi.
+  * Fixed compilation on NetBSD.
+  * Added sendKeyEvent() API.
+  * Fixed flickering on font change.
+  * Select all text when opening search bar.
+  * Removed some debug outputs.
+  * Removed (duplicated) string casts definitions.
+  * Removed obsolete qCopy.
+  * Fix SearchBar light text over white background with dark themes.
+  * pyqt: also check for sip 5.x path.
+  * Prevented a c++11 range-loop might detach Qt container.
+  * Dropped the deprecated QString method `sprintf()`.
+  * Avoid buffer overflows exploits.
+  * Fixed build with LLVM/clang.
+  * Explicitly mark exported classes.
+  * Fixed QCharRef's deprecated behavior.
+  * Correctly initialize sigsets.
+
 qtermwidget-0.14.1 / 2019-02-25
 ===============================
 
@@ -16,7 +55,7 @@ qtermwidget-0.14.0 / 2019-01-25
     - kpty: make it work on OpenBSD
     - kptyprocess: ensure .bash_history is correctly written out
     - kb-layouts: Make Backspace behaves the same as xterm
-    - tools: Drop the ability to bundle kb-layouts and colorschemes 
+    - tools: Drop the ability to bundle kb-layouts and colorschemes
     - SearchBar: Fix visual glitches in search-bar
     - TerminalDisplay: Fixed link mouseover after recent changes
     - TerminalDisplay: Redraw cursor after cursor type changed
@@ -24,9 +63,9 @@ qtermwidget-0.14.0 / 2019-01-25
     - qterminal: Correct deleting of HotSpot list items
     - qterminal: Removed unnecessary checks
     - ColorScheme: Fixed local variable will be copied despite being returned by name
-    - ColorScheme: Fixed error return-std-move 
+    - ColorScheme: Fixed error return-std-move
     - Removed unnecessary checks
-    - Suppressed compilation warnings 
+    - Suppressed compilation warnings
     - Don't use automatic string conversions
     - Marked some functions const
     - Implemented terminal margins
diff -pruN 0.14.1-3/.ci/build.sh 0.15.0-0ubuntu1/.ci/build.sh
--- 0.14.1-3/.ci/build.sh	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/.ci/build.sh	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,6 @@
+set -ex
+
+mkdir build
+cd build
+cmake -DBUILD_EXAMPLE=ON -DQTERMWIDGET_BUILD_PYTHON_BINDING=ON ..
+make
diff -pruN 0.14.1-3/CMakeLists.txt 0.15.0-0ubuntu1/CMakeLists.txt
--- 0.14.1-3/CMakeLists.txt	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/CMakeLists.txt	2020-04-24 03:22:14.000000000 +0000
@@ -21,8 +21,8 @@ option(USE_UTF8PROC "Use libutf8proc for
 
 # just change version for releases
 set(QTERMWIDGET_VERSION_MAJOR "0")
-set(QTERMWIDGET_VERSION_MINOR "14")
-set(QTERMWIDGET_VERSION_PATCH "1")
+set(QTERMWIDGET_VERSION_MINOR "15")
+set(QTERMWIDGET_VERSION_PATCH "0")
 
 set(QTERMWIDGET_VERSION "${QTERMWIDGET_VERSION_MAJOR}.${QTERMWIDGET_VERSION_MINOR}.${QTERMWIDGET_VERSION_PATCH}")
 
@@ -31,8 +31,8 @@ set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PAT
 set(CMAKE_INCLUDE_CURRENT_DIR ON)
 
 # Minimum Versions
-set(QT_MINIMUM_VERSION "5.7.1")
-set(LXQTBT_MINIMUM_VERSION "0.6.0")
+set(QT_MINIMUM_VERSION "5.10.0")
+set(LXQTBT_MINIMUM_VERSION "0.7.0")
 
 find_package(Qt5Widgets "${QT_MINIMUM_VERSION}" REQUIRED)
 find_package(Qt5LinguistTools "${QT_MINIMUM_VERSION}" REQUIRED)
@@ -47,6 +47,13 @@ include(LXQtTranslateTs)
 include(LXQtCompilerSettings NO_POLICY_SCOPE)
 include(LXQtCreatePkgConfigFile)
 
+if(APPLE)
+    if(CMAKE_VERSION VERSION_GREATER 3.9)
+        cmake_policy(SET CMP0068 NEW)
+        set(CMAKE_BUILD_WITH_INSTALL_NAME_DIR ON)
+    endif()
+endif()
+
 set(QTERMWIDGET_LIBRARY_NAME qtermwidget5)
 
 
@@ -197,17 +204,12 @@ target_compile_definitions(${QTERMWIDGET
         "TRANSLATIONS_DIR=\"${TRANSLATIONS_DIR}\""
         "HAVE_POSIX_OPENPT"
         "HAVE_SYS_TIME_H"
-        "QT_USE_QSTRINGBUILDER"
-        "QT_NO_CAST_FROM_ASCII"
-        "QT_NO_CAST_TO_ASCII"
-        "QT_NO_URL_CAST_FROM_STRING"
-        "QT_NO_CAST_FROM_BYTEARRAY"
 )
 
 
 generate_export_header(${QTERMWIDGET_LIBRARY_NAME}
     EXPORT_FILE_NAME "${CMAKE_CURRENT_BINARY_DIR}/lib/qtermwidget_export.h"
-    EXPORT_MACRO_NAME QTERMWIDGET_EXPORT
+    BASE_NAME QTERMWIDGET
 )
 
 target_include_directories(${QTERMWIDGET_LIBRARY_NAME}
@@ -238,7 +240,7 @@ install(EXPORT
 )
 
 install(FILES
-    ${HDRS_DISTRIB} "${CMAKE_CURRENT_BINARY_DIR}/lib/qtermwidget_export.h"
+    ${HDRS_DISTRIB} "${CMAKE_CURRENT_BINARY_DIR}/lib/qtermwidget_export.h" "${CMAKE_CURRENT_BINARY_DIR}/lib/qtermwidget_version.h"
     DESTINATION "${CMAKE_INSTALL_INCLUDEDIR}/${QTERMWIDGET_LIBRARY_NAME}"
     COMPONENT Devel
 )
@@ -275,6 +277,12 @@ configure_file(
     @ONLY
 )
 
+configure_file(
+    "${PROJECT_SOURCE_DIR}/lib/qtermwidget_version.h.in"
+    "${CMAKE_BINARY_DIR}/lib/qtermwidget_version.h"
+    @ONLY
+)
+
 install(FILES
     "${CMAKE_BINARY_DIR}/${QTERMWIDGET_LIBRARY_NAME}-config.cmake"
     DESTINATION "${CMAKE_INSTALL_LIBDIR}/cmake/${QTERMWIDGET_LIBRARY_NAME}"
diff -pruN 0.14.1-3/debian/changelog 0.15.0-0ubuntu1/debian/changelog
--- 0.14.1-3/debian/changelog	2020-02-23 21:16:09.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/changelog	2020-06-04 05:20:23.000000000 +0000
@@ -1,3 +1,21 @@
+qtermwidget (0.15.0-0ubuntu1) groovy; urgency=medium
+
+  * New upstream release.
+    - Update upstream signing key.
+    - Update LXQt build dependencies.
+    - Update symbols from amd64 build logs.
+  * Run wrap-and-sort.
+
+ -- Simon Quigley <tsimonq2@ubuntu.com>  Thu, 04 Jun 2020 00:20:23 -0500
+
+qtermwidget (0.14.1-3ubuntu1) focal; urgency=medium
+
+  * debian/control: Add Breaks/Replaces on qtermwidget-l10n to
+    qtermwidget5-data. Fixes upgrade from 0.14.1-0ubuntu3 or earlier.
+    (LP: #1864170)
+
+ -- Rik Mills <rikmills@kde.org>  Tue, 25 Feb 2020 16:24:33 +0000
+
 qtermwidget (0.14.1-3) unstable; urgency=medium
 
   * Bumped Standards-Version to 4.5.0, no changes needed
diff -pruN 0.14.1-3/debian/control 0.15.0-0ubuntu1/debian/control
--- 0.14.1-3/debian/control	2020-02-23 21:14:23.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/control	2020-06-04 05:20:23.000000000 +0000
@@ -1,14 +1,15 @@
 Source: qtermwidget
-Maintainer: LXQt Packaging Team <pkg-lxqt-devel@lists.alioth.debian.org>
+Maintainer: Lubuntu Developers <lubuntu-devel@lists.ubuntu.com>
+XSBC-Original-Maintainer: LXQt Packaging Team <pkg-lxqt-devel@lists.alioth.debian.org>
 Uploaders: Alf Gaida <agaida@siduction.org>,
            ChangZhuo Chen (陳昌倬) <czchen@debian.org>,
            Andrew Lee (李健秋) <ajqlee@debian.org>
 Section: libs
 Priority: optional
-Build-Depends: debhelper-compat (= 12),
-               cmake,
+Build-Depends: cmake,
+               debhelper-compat (= 12),
                libutf8proc-dev,
-               lxqt-build-tools (>= 0.6.0~),
+               lxqt-build-tools (>= 0.7.0),
                qtbase5-dev
 Standards-Version: 4.5.0
 Vcs-Browser: https://salsa.debian.org/lxqt-team/qtermwidget
@@ -19,9 +20,9 @@ Rules-Requires-Root: no
 Package: libqtermwidget5-0
 Architecture: any
 Multi-Arch: same
-Depends: ${shlibs:Depends},
+Depends: qtermwidget5-data (= ${source:Version}),
          ${misc:Depends},
-         qtermwidget5-data (= ${source:Version})
+         ${shlibs:Depends}
 Recommends: fonts-hack
 Pre-Depends: ${misc:Pre-Depends}
 Description: Terminal emulator widget for Qt 5 (shared libraries)
@@ -34,8 +35,7 @@ Package: libqtermwidget5-0-dev
 Architecture: any
 Multi-Arch: same
 Section: libdevel
-Depends: ${misc:Depends},
-         libqtermwidget5-0 (= ${binary:Version})
+Depends: libqtermwidget5-0 (= ${binary:Version}), ${misc:Depends}
 Description: Terminal emulator widget for Qt 5 (development files)
  QTermWidget is a Unicode-enabled, embeddable Qt widget that can be used as
  built-in console or terminal emulation widget.
@@ -46,6 +46,8 @@ Package: qtermwidget5-data
 Architecture: all
 Multi-Arch: foreign
 Depends: ${misc:Depends}
+Breaks: qtermwidget-l10n
+Replaces: qtermwidget-l10n
 Description: Terminal emulator widget for Qt 5 (data files)
  QTermWidget is a Unicode-enabled, embeddable Qt widget that can be used as
  built-in console or terminal emulation widget.
diff -pruN 0.14.1-3/debian/libqtermwidget5-0-dev.install 0.15.0-0ubuntu1/debian/libqtermwidget5-0-dev.install
--- 0.14.1-3/debian/libqtermwidget5-0-dev.install	2019-02-25 23:58:29.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/libqtermwidget5-0-dev.install	2020-06-04 05:20:16.000000000 +0000
@@ -1,6 +1,4 @@
 usr/include
-
+usr/lib/*/cmake/qtermwidget5/*.cmake
 usr/lib/*/libqtermwidget5.so
 usr/lib/*/pkgconfig/qtermwidget5.pc
-
-usr/lib/*/cmake/qtermwidget5/*.cmake
diff -pruN 0.14.1-3/debian/libqtermwidget5-0.symbols 0.15.0-0ubuntu1/debian/libqtermwidget5-0.symbols
--- 0.14.1-3/debian/libqtermwidget5-0.symbols	2019-10-26 19:41:39.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/libqtermwidget5-0.symbols	2020-06-04 05:20:16.000000000 +0000
@@ -43,6 +43,7 @@ libqtermwidget5.so.0 libqtermwidget5-0 #
  (c++)"QTermWidget::qt_metacast(char const*)@Base" 0.6.0
  (c++)"QTermWidget::receivedData(QString const&)@Base" 0.8.0
  (c++)"QTermWidget::resizeEvent(QResizeEvent*)@Base" 0.6.0
+ (c++)"QTermWidget::saveHistory(QIODevice*)@Base" 0.14.1+git20191205
  (c++)"QTermWidget::screenColumnsCount()@Base" 0.6.0
  (c++)"QTermWidget::screenLinesCount()@Base" 0.6.0
  (c++)"QTermWidget::scrollToEnd()@Base" 0.6.0
@@ -50,6 +51,7 @@ libqtermwidget5.so.0 libqtermwidget5-0 #
  (c++)"QTermWidget::selectedText(bool)@Base" 0.6.0
  (c++)"QTermWidget::selectionChanged(bool)@Base" 0.6.0
  (c++)"QTermWidget::sendData(char const*, int)@Base" 0.6.0
+ (c++)"QTermWidget::sendKeyEvent(QKeyEvent*)@Base" 0.14.1+git20191205
  (c++)"QTermWidget::sendText(QString const&)@Base" 0.6.0
  (c++)"QTermWidget::sessionFinished()@Base" 0.6.0
  (c++)"QTermWidget::setArgs(QStringList const&)@Base" 0.6.0
@@ -57,6 +59,7 @@ libqtermwidget5.so.0 libqtermwidget5-0 #
  (c++)"QTermWidget::setBidiEnabled(bool)@Base" 0.9.0~
  (c++)"QTermWidget::setBlinkingCursor(bool)@Base" 0.8.0
  (c++)"QTermWidget::setColorScheme(QString const&)@Base" 0.6.0
+ (c++)"QTermWidget::setDrawLineChars(bool)@Base" 0.14.1+git20191205
  (c++)"QTermWidget::setEnvironment(QStringList const&)@Base" 0.6.0
  (c++)"QTermWidget::setFlowControlEnabled(bool)@Base" 0.6.0
  (c++)"QTermWidget::setFlowControlWarningEnabled(bool)@Base" 0.6.0
@@ -96,6 +99,148 @@ libqtermwidget5.so.0 libqtermwidget5-0 #
  (c++)"QTermWidget::workingDirectory()@Base" 0.6.0
  (c++)"QTermWidget::zoomIn()@Base" 0.6.0
  (c++)"QTermWidget::zoomOut()@Base" 0.6.0
+ (c++)"Konsole::FilterChain::removeFilter(Konsole::Filter*)@Base" 0.15.0
+ (c++)"Konsole::FilterChain::containsFilter(Konsole::Filter*)@Base" 0.15.0
+ (c++)"Konsole::FilterChain::clear()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::reset()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::process()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::addFilter(Konsole::Filter*)@Base" 0.15.0
+ (c++)"Konsole::FilterChain::setBuffer(QString const*, QList<int> const*)@Base" 0.15.0
+ (c++)"Konsole::FilterChain::~FilterChain()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::~FilterChain()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::~FilterChain()@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::newHotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::HotSpot::setCapturedTexts(QStringList const&)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::HotSpot::activate(QString const&)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::process()@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::setRegExp(QRegExp const&)@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::RegExpFilter()@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::RegExpFilter()@Base" 0.15.0
+ (c++)"Konsole::Filter::addHotSpot(Konsole::Filter::HotSpot*)@Base" 0.15.0
+ (c++)"Konsole::Filter::getLineColumn(int, int&, int&)@Base" 0.15.0
+ (c++)"Konsole::Filter::reset()@Base" 0.15.0
+ (c++)"Konsole::Filter::buffer()@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::actions()@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::setType(Konsole::Filter::HotSpot::Type)@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::Filter::setBuffer(QString const*, QList<int> const*)@Base" 0.15.0
+ (c++)"Konsole::Filter::Filter()@Base" 0.15.0
+ (c++)"Konsole::Filter::Filter()@Base" 0.15.0
+ (c++)"Konsole::Filter::~Filter()@Base" 0.15.0
+ (c++)"Konsole::Filter::~Filter()@Base" 0.15.0
+ (c++)"Konsole::Filter::~Filter()@Base" 0.15.0
+ (c++)"Konsole::Emulation::sendString(char const*, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setHistory(Konsole::HistoryType const&)@Base" 0.15.0
+ (c++)"Konsole::Emulation::qt_metacall(QMetaObject::Call, int, void**)@Base" 0.15.0
+ (c++)"Konsole::Emulation::qt_metacast(char const*)@Base" 0.15.0
+ (c++)"Konsole::Emulation::receiveChar(wchar_t)@Base" 0.15.0
+ (c++)"Konsole::Emulation::receiveData(char const*, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::clearHistory()@Base" 0.15.0
+ (c++)"Konsole::Emulation::createWindow()@Base" 0.15.0
+ (c++)"Konsole::Emulation::sendKeyEvent(QKeyEvent*)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setImageSize(int, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::titleChanged(int, QString const&)@Base" 0.15.0
+ (c++)"Konsole::Emulation::cursorChanged(Konsole::Emulation::KeyboardCursorShape, bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::outputChanged()@Base" 0.15.0
+ (c++)"Konsole::Emulation::writeToStream(Konsole::TerminalCharacterDecoder*, int, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::bufferedUpdate()@Base" 0.15.0
+ (c++)"Konsole::Emulation::lockPtyRequest(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::sendMouseEvent(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setKeyBindings(QString const&)@Base" 0.15.0
+ (c++)"Konsole::Emulation::useUtf8Request(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::zmodemDetected()@Base" 0.15.0
+ (c++)"Konsole::Emulation::imageSizeChanged(int, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::staticMetaObject@Base" 0.15.0
+ (c++)"Konsole::Emulation::usesMouseChanged(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::imageResizeRequest(QSize const&)@Base" 0.15.0
+ (c++)"Konsole::Emulation::imageSizeInitialized()@Base" 0.15.0
+ (c++)"Konsole::Emulation::flowControlKeyPressed(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::programUsesMouseChanged(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::bracketedPasteModeChanged(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::changeTabTextColorRequest(int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::profileChangeCommandReceived(QString const&)@Base" 0.15.0
+ (c++)"Konsole::Emulation::programBracketedPasteModeChanged(bool)@Base" 0.15.0
+ (c++)"Konsole::Emulation::sendData(char const*, int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setCodec(Konsole::Emulation::EmulationCodec)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setCodec(QTextCodec const*)@Base" 0.15.0
+ (c++)"Konsole::Emulation::showBulk()@Base" 0.15.0
+ (c++)"Konsole::Emulation::stateSet(int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::setScreen(int)@Base" 0.15.0
+ (c++)"Konsole::Emulation::Emulation()@Base" 0.15.0
+ (c++)"Konsole::Emulation::Emulation()@Base" 0.15.0
+ (c++)"Konsole::Emulation::~Emulation()@Base" 0.15.0
+ (c++)"Konsole::Emulation::~Emulation()@Base" 0.15.0
+ (c++)"Konsole::Emulation::~Emulation()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::newHotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::qt_metacall(QMetaObject::Call, int, void**)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::qt_metacast(char const*)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::FullUrlRegExp@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::staticMetaObject@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::CompleteUrlRegExp@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::EmailAddressRegExp@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::actions()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::activate(QString const&)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::HotSpot(int, int, int, int)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::~HotSpot()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::activated(QUrl const&, bool)@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::UrlFilter()@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::UrlFilter()@Base" 0.15.0
+ (c++)"Konsole::FilterChain::hotSpots() const@Base" 0.15.0
+ (c++)"Konsole::FilterChain::hotSpotAt(int, int) const@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::regExp() const@Base" 0.15.0
+ (c++)"Konsole::RegExpFilter::HotSpot::capturedTexts() const@Base" 0.15.0
+ (c++)"Konsole::Filter::hotSpotsAtLine(int) const@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::startColumn() const@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::type() const@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::endLine() const@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::endColumn() const@Base" 0.15.0
+ (c++)"Konsole::Filter::HotSpot::startLine() const@Base" 0.15.0
+ (c++)"Konsole::Filter::hotSpots() const@Base" 0.15.0
+ (c++)"Konsole::Filter::hotSpotAt(int, int) const@Base" 0.15.0
+ (c++)"Konsole::Emulation::metaObject() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::keyBindings() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::programUsesMouse() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::programBracketedPasteMode() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::history() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::eraseChar() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::imageSize() const@Base" 0.15.0
+ (c++)"Konsole::Emulation::lineCount() const@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::metaObject() const@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::getUrlObject() const@Base" 0.15.0
+ (c++)"Konsole::UrlFilter::HotSpot::urlType() const@Base" 0.15.0
+ (c++)"typeinfo for Konsole::FilterChain@Base" 0.15.0
+ (c++)"typeinfo for Konsole::RegExpFilter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo for Konsole::RegExpFilter@Base" 0.15.0
+ (c++)"typeinfo for Konsole::Filter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo for Konsole::Filter@Base" 0.15.0
+ (c++)"typeinfo for Konsole::Emulation@Base" 0.15.0
+ (c++)"typeinfo for Konsole::UrlFilter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo for Konsole::UrlFilter@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::FilterChain@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::RegExpFilter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::RegExpFilter@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::Filter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::Filter@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::Emulation@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::UrlFilter::HotSpot@Base" 0.15.0
+ (c++)"typeinfo name for Konsole::UrlFilter@Base" 0.15.0
+ (c++)"vtable for Konsole::FilterChain@Base" 0.15.0
+ (c++)"vtable for Konsole::RegExpFilter::HotSpot@Base" 0.15.0
+ (c++)"vtable for Konsole::RegExpFilter@Base" 0.15.0
+ (c++)"vtable for Konsole::Filter::HotSpot@Base" 0.15.0
+ (c++)"vtable for Konsole::Filter@Base" 0.15.0
+ (c++)"vtable for Konsole::Emulation@Base" 0.15.0
+ (c++)"vtable for Konsole::UrlFilter::HotSpot@Base" 0.15.0
+ (c++)"vtable for Konsole::UrlFilter@Base" 0.15.0
  (c++)"QTermWidget::~QTermWidget()@Base" 0.6.0
  (c++)"non-virtual thunk to QTermWidget::~QTermWidget()@Base" 0.6.0
  (c++)"typeinfo for QTermWidget@Base" 0.6.0
diff -pruN 0.14.1-3/debian/qtermwidget5-data.install 0.15.0-0ubuntu1/debian/qtermwidget5-data.install
--- 0.14.1-3/debian/qtermwidget5-data.install	2019-02-25 23:58:29.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/qtermwidget5-data.install	2020-06-04 05:20:16.000000000 +0000
@@ -1,4 +1,3 @@
 usr/share/qtermwidget5/color-schemes
 usr/share/qtermwidget5/kb-layouts
-
 usr/share/qtermwidget5/translations
diff -pruN 0.14.1-3/debian/upstream/signing-key.asc 0.15.0-0ubuntu1/debian/upstream/signing-key.asc
--- 0.14.1-3/debian/upstream/signing-key.asc	2019-02-25 23:58:29.000000000 +0000
+++ 0.15.0-0ubuntu1/debian/upstream/signing-key.asc	2020-06-04 05:20:16.000000000 +0000
@@ -1,50 +1,52 @@
------BEGIN PGP PUBLIC KEY BLOCK-----
-
-mQINBFXQeMMBEACif4+9pTrC6uNmRng0ZbzLh7p3cazmbnp2YFgDQDJZ7ZNmebxy
-ngRuRhjGuDcFAL/37BwJnrBpfZFK9ljoH4Fo5Jm9cOELaTy7AIcEiV9dKMyrKF1E
-C76d8jHVuzuPbI92DkFdLZAdk+qjrrAy0x43PvUd+aaBGLcFs1ZMk7gOvElc2d95
-zWWSp5anjukmGbp+EsStnWJkF6VHj56qmklfYy5ioiVBOSpXo/RsACAcIlz8C8A1
-d4tNMiB2uF2OrUfrL8DD6m3nBqep+AYbIQrxMl9kUQH3I33e9kH/L+SHQyE6phS8
-Czq06WjV4TcJ9VWxm7hQCNLYSxhZYYr1AW45lS5+xmfBOq2qeLgvjbFxa8PPrsp6
-Bqgt8MjwUkXjU5IB7YulUBvFU2l0MJZWDBuNy0oNtCe1cU3JyIqLKjvzQQQ9eD5L
-o3Ul704TLHz0z+67Rxh05Mi4JvyFMjnooSJkNH8/7yXoBN0ZGOh1/5zMU1gK5bmP
-6hKgis2exSZNIS74mF6/PqGgcwk3PyI4T3keUQoNPj11M2EznLHxY19QZfQ5oMed
-8xOlHKjpcm8PYMB4gduNXlV7gI9h7UxuC5GuPiP2lmM6wUyHu48divxDk5UYgPEC
-xlPI2wHCNDsuy0EruCYIvrMSZfpYCCSrmXiOORBLO5qXkauILLkJarHqjQARAQAB
-tCBBbGYgR2FpZGEgPGFnYWlkYUBzaWR1Y3Rpb24ub3JnPokCOAQTAQIAIgUCVdB4
-wwIbAwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQQsnI069epeOT2xAAgSHf
-41103cnElGf6TokPl4J6hdRPy2CUAjmBtMfr8eajYvGDGgnmsh9AGYGURjfFVCCf
-Ag+8b6nF3xg03UmgsuSO8H78HGv9kKzF9aHmLt+SXq3jUX+LnIkFHErZWjFAKdJr
-luu1j6ltxLe9PQljxZnugzMaUbW8eEPKvcriiDn3S4/DtikW/jpGA0MTY4ZWs9pZ
-L/6iRRH99L2X/cWO4sCgDXCTt4oK0f5OvwiuCoVOM+PYoIm31JICCKOlqamkCn7d
-2KH3nsy0v7tXgnrnb/zr8jVGsZLzUE51AFOzb5Ec74/2SAq8X4gbTppttLXEIooq
-nbepitW/PePkPY5gpfwHtFbl88qFnir+ABMefqRZkzeh0tsxJVLVHGP1KZykXpv7
-96A6Q1h7Zo9Ny7WwN5Xl02g35LVCaPyzd3A8A4315uMuP3iziq57UktKqh9d5S3t
-jfK7e9UfFQZBLfxn2sNPsjdYSNUQp/PXTTk/599h359WVuUIR866T8K7N7EEon3p
-qLItZljQ9Nmr/yGwKi9iQgi2LtZj5KUcF1zBLzZKf95FvoqSZqBXdFSjm+eYGaCH
-Q2IBnhyP92lEknSK9ystUJXmY69tQKBFqJxScwaS+7a/rfLKssQjSWxqk+SX4QeW
-e9z9FUpo71bq0Zkc/M9aOCoEEmhg4Ob/JWy08oC5Ag0EVdB4wwEQAKZDCc/C41y0
-omLFCAJybvHiFScM+jOpyGpQvceoviEhIT7h1br/pnSEMkgPQEDPWJGtKueg1/94
-sXTH24uefr3Y6JdZoBtprxl4JXUoOndgq1QH1xuUsy3/9YWU8Qboy9j8a8w0oCDE
-T8Z03KHCwqzD3K+44jhmhF+0eLoaaY8ohS8ziP+DcFKVHyatmS5yCCdjVrj6PxMp
-uy/y5SXT1kmiPdVAIzQlM5DlN6o46TV+BH0pPvVYjtwf31o0FckJxy5S1v0koCNB
-vX2b7tTDPKzn8G18eUVhGoUTZBUCp1gg36wJ0YY4xgZ9vI/xDCeHeAkyvGtaTAoy
-qP4rHoUO5KVRSDh7frSlrdbLGWHaQwOhcqoKd4qP/164wHPGkgHL1vztdOc7l1wx
-q3gMh2uwmJR0NRrw4WVuaIqL9lEbGBNijlmGsuqXfsMRhc/qoqgVDWvrcCtEoOwl
-TONGobW3jpCCjpa9SeGNjxuY6IVLn0lfX4hItNVY9sFA+H+yj4uBQ7zsmMUXafxt
-Yllm0f98yGNg5lnJg4bLOYu3IkpogUKNA3qkZ+6vRtwH70/bJGp7qdx/3G4W5dMX
-asd/rJjdELW+R/NVULAmK1ETSklaa3Z6vbTu8bN8gvP8pmMJ8f/U8+qzkuAqc201
-Z4O+s7ZsQfTiz5mm7zPGIYTnppDSno/rABEBAAGJAh8EGAECAAkFAlXQeMMCGwwA
-CgkQQsnI069epeMt0g/+JrwLhULD6NOxaLgxboh/KZkh/7ViU4cB+QPT8JIcWxkZ
-zj8uk85TUitEUzKmjp/ItCrhQE5WNNWbz/FBnAuLtaQuHhcHMA3Vu95UUCGi1vyZ
-ZRlS3YRM6S9BOzrjG7fGQJmO/RU3g6rb0TAwGFxDHj8t4JEDTc3zASG7wV/VTn06
-d8XIH9CZOw3kUuhkQ3OR/PEj1BCeCC+caC+tBjO0fgvDp8RV7NFQQ9kH8R3/xlWd
-6KMPtILE6fUft6LubWRGd1P5JBuzXivELolASajewbYtL/s87CCji3ngq0aT9raK
-m02wqFzNbX1iv+w2iqPQXq6pdRyxtJ8+Q8Z7zEBGJS5nkrYjsLTduZIjJHYHYH7f
-3/ydVjQ3z12iqHKElgaRI7RUmpNiNxVIr+TtuxzeC6G+CF++XNkUtJODvCmRaoJS
-waYsitz8+LSv3tawZJ0iQkKc9nerQMuBD+AzIr3i4NgXiEIN513esUtnKzeyIIsL
-ntUcBjXKuLCj8OZrZtexjq7edWWbN57/3ikyS2Z7y0i3O30qk5jmccSaS6kA7xTY
-WCDFzbN2v2y+vGu9KYn+2HtrP2BtNa8JTh3waNeLUTpn4GV4mMrsZjOy6vhhHb91
-1TKfI1gvjk7lE9xaWmcDjdI55dw3jIq8kK9SdgORGq9/S3g7KJNRjme+6GjqQfk=
-=h7ww
+-----BEGIN PGP PUBLIC KEY BLOCK-----
+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+=gSIv
 -----END PGP PUBLIC KEY BLOCK-----
diff -pruN 0.14.1-3/example/main.cpp 0.15.0-0ubuntu1/example/main.cpp
--- 0.14.1-3/example/main.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/example/main.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -28,25 +28,30 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    QIcon::setThemeName("oxygen");
+    QIcon::setThemeName(QStringLiteral("oxygen"));
     QMainWindow *mainWindow = new QMainWindow();
 
     QTermWidget *console = new QTermWidget();
 
     QMenuBar *menuBar = new QMenuBar(mainWindow);
-    QMenu *actionsMenu = new QMenu("Actions", menuBar);
+    QMenu *actionsMenu = new QMenu(QStringLiteral("Actions"), menuBar);
     menuBar->addMenu(actionsMenu);
-    actionsMenu->addAction("Find..", console, SLOT(toggleShowSearchBar()), QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F));
-    actionsMenu->addAction("About Qt", &app, SLOT(aboutQt()));
+    actionsMenu->addAction(QStringLiteral("Find..."), console, &QTermWidget::toggleShowSearchBar,
+                           QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F));
+    actionsMenu->addAction(QStringLiteral("Copy"), console, &QTermWidget::copyClipboard,
+                           QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_C));
+    actionsMenu->addAction(QStringLiteral("Paste"), console, &QTermWidget::pasteClipboard,
+                           QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_V));
+    actionsMenu->addAction(QStringLiteral("About Qt"), &app, &QApplication::aboutQt);
     mainWindow->setMenuBar(menuBar);
 
     QFont font = QApplication::font();
-#ifdef Q_WS_MAC
-    font.setFamily("Monaco");
+#ifdef Q_OS_MACOS
+    font.setFamily(QStringLiteral("Monaco"));
 #elif defined(Q_WS_QWS)
-    font.setFamily("fixed");
+    font.setFamily(QStringLiteral("fixed"));
 #else
-    font.setFamily("Monospace");
+    font.setFamily(QStringLiteral("Monospace"));
 #endif
     font.setPointSize(12);
 
@@ -75,7 +80,7 @@ int main(int argc, char *argv[])
     qDebug() << "* INFO END *********************";
 
     // real startup
-    QObject::connect(console, SIGNAL(finished()), mainWindow, SLOT(close()));
+    QObject::connect(console, &QTermWidget::finished, mainWindow, &QMainWindow::close);
 
     mainWindow->show();
     return app.exec();
diff -pruN 0.14.1-3/lib/BlockArray.cpp 0.15.0-0ubuntu1/lib/BlockArray.cpp
--- 0.14.1-3/lib/BlockArray.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/BlockArray.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -30,7 +30,7 @@
 #include <sys/mman.h>
 #include <sys/param.h>
 #include <unistd.h>
-#include <stdio.h>
+#include <cstdio>
 
 
 using namespace Konsole;
@@ -41,9 +41,9 @@ BlockArray::BlockArray()
         : size(0),
         current(size_t(-1)),
         index(size_t(-1)),
-        lastmap(0),
+        lastmap(nullptr),
         lastmap_index(size_t(-1)),
-        lastblock(0), ion(-1),
+        lastblock(nullptr), ion(-1),
         length(0)
 {
     // lastmap_index = index = current = size_t(-1);
@@ -138,7 +138,7 @@ const Block * BlockArray::at(size_t i)
 
     if (i > index) {
         qDebug() << "BlockArray::at() i > index\n";
-        return 0;
+        return nullptr;
     }
 
 //     if (index - i >= length) {
@@ -151,11 +151,11 @@ const Block * BlockArray::at(size_t i)
     Q_ASSERT(j < size);
     unmap();
 
-    Block * block = (Block *)mmap(0, blocksize, PROT_READ, MAP_PRIVATE, ion, j * blocksize);
+    Block * block = (Block *)mmap(nullptr, blocksize, PROT_READ, MAP_PRIVATE, ion, j * blocksize);
 
     if (block == (Block *)-1) {
         perror("mmap");
-        return 0;
+        return nullptr;
     }
 
     lastmap = block;
@@ -172,7 +172,7 @@ void BlockArray::unmap()
             perror("munmap");
         }
     }
-    lastmap = 0;
+    lastmap = nullptr;
     lastmap_index = size_t(-1);
 }
 
@@ -193,7 +193,7 @@ bool BlockArray::setHistorySize(size_t n
 
     if (!newsize) {
         delete lastblock;
-        lastblock = 0;
+        lastblock = nullptr;
         if (ion >= 0) {
             close(ion);
         }
diff -pruN 0.14.1-3/lib/BlockArray.h 0.15.0-0ubuntu1/lib/BlockArray.h
--- 0.14.1-3/lib/BlockArray.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/BlockArray.h	2020-04-24 03:22:14.000000000 +0000
@@ -27,8 +27,8 @@
 
 //#error Do not use in KDE 2.1
 
-#define BlockSize (1 << 12)
-#define ENTRIES   ((BlockSize - sizeof(size_t) ) / sizeof(unsigned char))
+#define QTERMWIDGET_BLOCKSIZE (1 << 12)
+#define ENTRIES   ((QTERMWIDGET_BLOCKSIZE - sizeof(size_t) ) / sizeof(unsigned char))
 
 namespace Konsole {
 
diff -pruN 0.14.1-3/lib/CharacterColor.h 0.15.0-0ubuntu1/lib/CharacterColor.h
--- 0.14.1-3/lib/CharacterColor.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/CharacterColor.h	2020-04-24 03:22:14.000000000 +0000
@@ -278,7 +278,7 @@ inline QColor CharacterColor::color(cons
     case COLOR_SPACE_DEFAULT: return base[_u+0+(_v?BASE_COLORS:0)].color;
     case COLOR_SPACE_SYSTEM: return base[_u+2+(_v?BASE_COLORS:0)].color;
     case COLOR_SPACE_256: return color256(_u,base);
-    case COLOR_SPACE_RGB: return QColor(_u,_v,_w);
+    case COLOR_SPACE_RGB: return {_u,_v,_w};
     case COLOR_SPACE_UNDEFINED: return QColor();
   }
 
diff -pruN 0.14.1-3/lib/ColorScheme.cpp 0.15.0-0ubuntu1/lib/ColorScheme.cpp
--- 0.14.1-3/lib/ColorScheme.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/ColorScheme.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -48,27 +48,27 @@ const ColorEntry ColorScheme::defaultTab
  // gamma correction for the dim colors to compensate for bright X screens.
  // It contains the 8 ansiterm/xterm colors in 2 intensities.
 {
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 1), // Dfore, Dback
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xB2,0x18,0x18), 0), // Black, Red
-    ColorEntry( QColor(0x18,0xB2,0x18), 0), ColorEntry(
-QColor(0xB2,0x68,0x18), 0), // Green, Yellow
-    ColorEntry( QColor(0x18,0x18,0xB2), 0), ColorEntry(
-QColor(0xB2,0x18,0xB2), 0), // Blue, Magenta
-    ColorEntry( QColor(0x18,0xB2,0xB2), 0), ColorEntry(
-QColor(0xB2,0xB2,0xB2), 0), // Cyan, White
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), true), // Dfore, Dback
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xB2,0x18,0x18), false), // Black, Red
+    ColorEntry( QColor(0x18,0xB2,0x18), false), ColorEntry(
+QColor(0xB2,0x68,0x18), false), // Green, Yellow
+    ColorEntry( QColor(0x18,0x18,0xB2), false), ColorEntry(
+QColor(0xB2,0x18,0xB2), false), // Blue, Magenta
+    ColorEntry( QColor(0x18,0xB2,0xB2), false), ColorEntry(
+QColor(0xB2,0xB2,0xB2), false), // Cyan, White
     // intensive
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 1),
-    ColorEntry( QColor(0x68,0x68,0x68), 0), ColorEntry(
-QColor(0xFF,0x54,0x54), 0),
-    ColorEntry( QColor(0x54,0xFF,0x54), 0), ColorEntry(
-QColor(0xFF,0xFF,0x54), 0),
-    ColorEntry( QColor(0x54,0x54,0xFF), 0), ColorEntry(
-QColor(0xFF,0x54,0xFF), 0),
-    ColorEntry( QColor(0x54,0xFF,0xFF), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 0)
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), true),
+    ColorEntry( QColor(0x68,0x68,0x68), false), ColorEntry(
+QColor(0xFF,0x54,0x54), false),
+    ColorEntry( QColor(0x54,0xFF,0x54), false), ColorEntry(
+QColor(0xFF,0xFF,0x54), false),
+    ColorEntry( QColor(0x54,0x54,0xFF), false), ColorEntry(
+QColor(0xFF,0x54,0xFF), false),
+    ColorEntry( QColor(0x54,0xFF,0xFF), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), false)
 };
 
 const char* const ColorScheme::colorNames[TABLE_COLORS] =
@@ -122,25 +122,25 @@ const char* const ColorScheme::translate
 
 ColorScheme::ColorScheme()
 {
-    _table = 0;
-    _randomTable = 0;
+    _table = nullptr;
+    _randomTable = nullptr;
     _opacity = 1.0;
 }
 ColorScheme::ColorScheme(const ColorScheme& other)
       : _opacity(other._opacity)
-       ,_table(0)
-       ,_randomTable(0)
+       ,_table(nullptr)
+       ,_randomTable(nullptr)
 {
     setName(other.name());
     setDescription(other.description());
 
-    if ( other._table != 0 )
+    if ( other._table != nullptr )
     {
         for ( int i = 0 ; i < TABLE_COLORS ; i++ )
             setColorTableEntry(i,other._table[i]);
     }
 
-    if ( other._randomTable != 0 )
+    if ( other._randomTable != nullptr )
     {
         for ( int i = 0 ; i < TABLE_COLORS ; i++ )
         {
@@ -185,7 +185,7 @@ ColorEntry ColorScheme::colorEntry(int i
     ColorEntry entry = colorTable()[index];
 
     if ( randomSeed != 0 &&
-        _randomTable != 0 &&
+        _randomTable != nullptr &&
         !_randomTable[index].isNull() )
     {
         const RandomizationRange& range = _randomTable[index];
@@ -213,7 +213,7 @@ void ColorScheme::getColorTable(ColorEnt
 }
 bool ColorScheme::randomizedBackgroundColor() const
 {
-    return _randomTable == 0 ? false : !_randomTable[1].isNull();
+    return _randomTable == nullptr ? false : !_randomTable[1].isNull();
 }
 void ColorScheme::setRandomizedBackgroundColor(bool randomize)
 {
@@ -238,7 +238,7 @@ void ColorScheme::setRandomizationRange(
     Q_ASSERT( hue <= MAX_HUE );
     Q_ASSERT( index >= 0 && index < TABLE_COLORS );
 
-    if ( _randomTable == 0 )
+    if ( _randomTable == nullptr )
         _randomTable = new RandomizationRange[TABLE_COLORS];
 
     _randomTable[index].hue = hue;
@@ -594,7 +594,7 @@ ColorSchemeManager::~ColorSchemeManager(
 }
 void ColorSchemeManager::loadAllColorSchemes()
 {
-    qDebug() << "loadAllColorSchemes";
+    //qDebug() << "loadAllColorSchemes";
     int failed = 0;
 
     QList<QString> nativeColorSchemes = listColorSchemes();
@@ -613,8 +613,8 @@ void ColorSchemeManager::loadAllColorSch
             failed++;
     }
 
-    if ( failed > 0 )
-        qDebug() << "failed to load " << failed << " color schemes.";
+    /*if ( failed > 0 )
+        qDebug() << "failed to load " << failed << " color schemes.";*/
 
     _haveLoadedAll = true;
 }
@@ -640,7 +640,7 @@ bool ColorSchemeManager::loadKDE3ColorSc
 
     if (scheme->name().isEmpty())
     {
-        qDebug() << "color scheme name is not valid.";
+        //qDebug() << "color scheme name is not valid.";
         delete scheme;
         return false;
     }
@@ -651,8 +651,8 @@ bool ColorSchemeManager::loadKDE3ColorSc
         _colorSchemes.insert(scheme->name(),scheme);
     else
     {
-        qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
-            "found, ignoring.";
+        /*qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
+            "found, ignoring.";*/
         delete scheme;
     }
 
@@ -701,7 +701,7 @@ bool ColorSchemeManager::loadColorScheme
 
     if (scheme->name().isEmpty())
     {
-        qDebug() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
+        //qDebug() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
         delete scheme;
         return false;
     }
@@ -712,8 +712,8 @@ bool ColorSchemeManager::loadColorScheme
     }
     else
     {
-        qDebug() << "color scheme with name" << schemeName << "has already been" <<
-            "found, ignoring.";
+        /*qDebug() << "color scheme with name" << schemeName << "has already been" <<
+            "found, ignoring.";*/
 
         delete scheme;
     }
@@ -730,7 +730,7 @@ QList<QString> ColorSchemeManager::listK
         QStringList filters;
         filters << QLatin1String("*.schema");
         dir.setNameFilters(filters);
-        QStringList list = dir.entryList(filters);
+        const QStringList list = dir.entryList(filters);
         for (const QString &i : list)
             ret << dname + QLatin1Char('/') + i;
     }
@@ -750,7 +750,7 @@ QList<QString> ColorSchemeManager::listC
         QStringList filters;
         filters << QLatin1String("*.colorscheme");
         dir.setNameFilters(filters);
-        QStringList list = dir.entryList(filters);
+        const QStringList list = dir.entryList(filters);
         for (const QString &i : list)
             ret << dname + QLatin1Char('/') + i;
     }
@@ -777,7 +777,7 @@ bool ColorSchemeManager::deleteColorSche
     }
     else
     {
-        qDebug() << "Failed to remove color scheme -" << path;
+        //qDebug() << "Failed to remove color scheme -" << path;
         return false;
     }
 }
@@ -819,9 +819,9 @@ const ColorScheme* ColorSchemeManager::f
                 return findColorScheme(name);
         }
 
-        qDebug() << "Could not find color scheme - " << name;
+        //qDebug() << "Could not find color scheme - " << name;
 
-        return 0;
+        return nullptr;
     }
 }
 Q_GLOBAL_STATIC(ColorSchemeManager, theColorSchemeManager)
diff -pruN 0.14.1-3/lib/Emulation.cpp 0.15.0-0ubuntu1/lib/Emulation.cpp
--- 0.14.1-3/lib/Emulation.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Emulation.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -23,8 +23,8 @@
 #include "Emulation.h"
 
 // System
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
 #include <unistd.h>
 #include <string>
 
@@ -51,10 +51,10 @@
 using namespace Konsole;
 
 Emulation::Emulation() :
-  _currentScreen(0),
-  _codec(0),
-  _decoder(0),
-  _keyTranslator(0),
+  _currentScreen(nullptr),
+  _codec(nullptr),
+  _decoder(nullptr),
+  _keyTranslator(nullptr),
   _usesMouse(false),
   _bracketedPasteMode(false)
 {
@@ -380,7 +380,7 @@ void Emulation::setImageSize(int lines,
 
 QSize Emulation::imageSize() const
 {
-  return QSize(_currentScreen->getColumns(), _currentScreen->getLines());
+  return {_currentScreen->getColumns(), _currentScreen->getLines()};
 }
 
 ushort ExtendedCharTable::extendedCharHash(ushort* unicodePoints , ushort length) const
@@ -398,7 +398,7 @@ bool ExtendedCharTable::extendedCharMatc
 
     // compare given length with stored sequence length ( given as the first ushort in the
     // stored buffer )
-    if ( entry == 0 || entry[0] != length )
+    if ( entry == nullptr || entry[0] != length )
        return false;
     // if the lengths match, each character must be checked.  the stored buffer starts at
     // entry[1]
@@ -458,7 +458,7 @@ ushort* ExtendedCharTable::lookupExtende
     else
     {
         length = 0;
-        return 0;
+        return nullptr;
     }
 }
 
diff -pruN 0.14.1-3/lib/Emulation.h 0.15.0-0ubuntu1/lib/Emulation.h
--- 0.14.1-3/lib/Emulation.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Emulation.h	2020-04-24 03:22:14.000000000 +0000
@@ -24,7 +24,7 @@
 #define EMULATION_H
 
 // System
-#include <stdio.h>
+#include <cstdio>
 
 // Qt
 #include <QKeyEvent>
@@ -33,9 +33,7 @@
 #include <QTextStream>
 #include <QTimer>
 
-// Konsole
-//#include "konsole_export.h"
-#define KONSOLEPRIVATE_EXPORT
+#include "qtermwidget_export.h"
 
 namespace Konsole
 {
@@ -120,7 +118,7 @@ enum
  * how long the emulation has been active/idle for and also respond to
  * a 'bell' event in different ways.
  */
-class KONSOLEPRIVATE_EXPORT Emulation : public QObject
+class QTERMWIDGET_EXPORT Emulation : public QObject
 {
 Q_OBJECT
 
@@ -148,7 +146,7 @@ public:
 
    /** Constructs a new terminal emulation */
    Emulation();
-  ~Emulation();
+  ~Emulation() override;
 
   /**
    * Creates a new window onto the output from this emulation.  The contents
diff -pruN 0.14.1-3/lib/Filter.cpp 0.15.0-0ubuntu1/lib/Filter.cpp
--- 0.14.1-3/lib/Filter.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Filter.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -98,13 +98,13 @@ Filter::HotSpot* FilterChain::hotSpotAt(
     {
         Filter* filter = iter.next();
         Filter::HotSpot* spot = filter->hotSpotAt(line,column);
-        if ( spot != 0 )
+        if ( spot != nullptr )
         {
             return spot;
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 QList<Filter::HotSpot*> FilterChain::hotSpots() const
@@ -121,8 +121,8 @@ QList<Filter::HotSpot*> FilterChain::hot
 //QList<Filter::HotSpot*> FilterChain::hotSpotsAtLine(int line) const;
 
 TerminalImageFilterChain::TerminalImageFilterChain()
-: _buffer(0)
-, _linePositions(0)
+: _buffer(nullptr)
+, _linePositions(nullptr)
 {
 }
 
@@ -180,8 +180,8 @@ void TerminalImageFilterChain::setImage(
 }
 
 Filter::Filter() :
-_linePositions(0),
-_buffer(0)
+_linePositions(nullptr),
+_buffer(nullptr)
 {
 }
 
@@ -275,7 +275,7 @@ Filter::HotSpot* Filter::hotSpotAt(int l
         return spot;
     }
 
-    return 0;
+    return nullptr;
 }
 
 Filter::HotSpot::HotSpot(int startLine , int startColumn , int endLine , int endColumn)
diff -pruN 0.14.1-3/lib/Filter.h 0.15.0-0ubuntu1/lib/Filter.h
--- 0.14.1-3/lib/Filter.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Filter.h	2020-04-24 03:22:14.000000000 +0000
@@ -29,6 +29,7 @@
 #include <QRegExp>
 
 // Local
+#include "qtermwidget_export.h"
 
 namespace Konsole
 {
@@ -54,7 +55,7 @@ class Character;
  * When processing the text they should create instances of Filter::HotSpot subclasses for sections of interest
  * and add them to the filter's list of hotspots using addHotSpot()
  */
-class Filter : public QObject
+class QTERMWIDGET_EXPORT Filter : public QObject
 {
 public:
     /**
@@ -132,7 +133,7 @@ public:
 
     /** Constructs a new filter. */
     Filter();
-    virtual ~Filter();
+    ~Filter() override;
 
     /** Causes the filter to process the block of text currently in its internal buffer */
     virtual void process() = 0;
@@ -183,7 +184,7 @@ private:
  * Subclasses can reimplement newHotSpot() to return custom hotspot types when matches for the regular expression
  * are found.
  */
-class RegExpFilter : public Filter
+class QTERMWIDGET_EXPORT RegExpFilter : public Filter
 {
 public:
     /**
@@ -194,7 +195,7 @@ public:
     {
     public:
         HotSpot(int startLine, int startColumn, int endLine , int endColumn);
-        virtual void activate(const QString& action = QString());
+        void activate(const QString& action = QString()) override;
 
         /** Sets the captured texts associated with this hotspot */
         void setCapturedTexts(const QStringList& texts);
@@ -223,7 +224,7 @@ public:
      * If regexp matches the empty string, then process() will return immediately
      * without finding results.
      */
-    virtual void process();
+    void process() override;
 
 protected:
     /**
@@ -240,7 +241,7 @@ private:
 class FilterObject;
 
 /** A filter which matches URLs in blocks of text */
-class UrlFilter : public RegExpFilter
+class QTERMWIDGET_EXPORT UrlFilter : public RegExpFilter
 {
     Q_OBJECT
 public:
@@ -252,17 +253,17 @@ public:
     {
     public:
         HotSpot(int startLine,int startColumn,int endLine,int endColumn);
-        virtual ~HotSpot();
+        ~HotSpot() override;
 
         FilterObject* getUrlObject() const;
 
-        virtual QList<QAction*> actions();
+        QList<QAction*> actions() override;
 
         /**
          * Open a web browser at the current URL.  The url itself can be determined using
          * the capturedTexts() method.
          */
-        virtual void activate(const QString& action = QString());
+        void activate(const QString& action = QString()) override;
 
     private:
         enum UrlType
@@ -279,7 +280,7 @@ public:
     UrlFilter();
 
 protected:
-    virtual RegExpFilter::HotSpot* newHotSpot(int,int,int,int);
+    RegExpFilter::HotSpot* newHotSpot(int,int,int,int) override;
 
 private:
 
@@ -292,7 +293,7 @@ signals:
     void activated(const QUrl& url, bool fromContextMenu);
 };
 
-class FilterObject : public QObject
+class QTERMWIDGET_NO_EXPORT FilterObject : public QObject
 {
     Q_OBJECT
 public:
@@ -324,7 +325,7 @@ signals:
  * The hotSpots() and hotSpotsAtLine() method return all of the hotspots in the text and on
  * a given line respectively.
  */
-class FilterChain : protected QList<Filter*>
+class QTERMWIDGET_EXPORT FilterChain : protected QList<Filter*>
 {
 public:
     virtual ~FilterChain();
@@ -358,11 +359,11 @@ public:
 };
 
 /** A filter chain which processes character images from terminal displays */
-class TerminalImageFilterChain : public FilterChain
+class QTERMWIDGET_NO_EXPORT TerminalImageFilterChain : public FilterChain
 {
 public:
     TerminalImageFilterChain();
-    virtual ~TerminalImageFilterChain();
+    ~TerminalImageFilterChain() override;
 
     /**
      * Set the current terminal image to @p image.
diff -pruN 0.14.1-3/lib/History.cpp 0.15.0-0ubuntu1/lib/History.cpp
--- 0.14.1-3/lib/History.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/History.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -22,13 +22,14 @@
 #include "History.h"
 
 // System
+#include <algorithm>
 #include <iostream>
-#include <stdlib.h>
-#include <stdio.h>
+#include <cstdlib>
+#include <cstdio>
 #include <sys/types.h>
 #include <sys/mman.h>
 #include <unistd.h>
-#include <errno.h>
+#include <cerrno>
 
 #include <QtDebug>
 
@@ -89,7 +90,7 @@ FIXME: There is noticeable decrease in s
 HistoryFile::HistoryFile()
   : ion(-1),
     length(0),
-    fileMap(0)
+    fileMap(nullptr)
 {
   if (tmpFile.open())
   {
@@ -109,15 +110,15 @@ HistoryFile::~HistoryFile()
 //to avoid this.
 void HistoryFile::map()
 {
-    Q_ASSERT( fileMap == 0 );
+    Q_ASSERT( fileMap == nullptr );
 
-    fileMap = (char*)mmap( 0 , length , PROT_READ , MAP_PRIVATE , ion , 0 );
+    fileMap = (char*)mmap( nullptr , length , PROT_READ , MAP_PRIVATE , ion , 0 );
 
     //if mmap'ing fails, fall back to the read-lseek combination
     if ( fileMap == MAP_FAILED )
     {
             readWriteBalance = 0;
-            fileMap = 0;
+            fileMap = nullptr;
             //qDebug() << __FILE__ << __LINE__ << ": mmap'ing history failed.  errno = " << errno;
     }
 }
@@ -127,12 +128,12 @@ void HistoryFile::unmap()
     int result = munmap( fileMap , length );
     Q_ASSERT( result == 0 ); Q_UNUSED( result );
 
-    fileMap = 0;
+    fileMap = nullptr;
 }
 
 bool HistoryFile::isMapped() const
 {
-    return (fileMap != 0);
+    return (fileMap != nullptr);
 }
 
 void HistoryFile::add(const unsigned char* bytes, int len)
@@ -313,7 +314,7 @@ void HistoryScrollBuffer::addCellsVector
 void HistoryScrollBuffer::addCells(const Character a[], int count)
 {
   HistoryLine newLine(count);
-  qCopy(a,a+count,newLine.begin());
+  std::copy(a,a+count,newLine.begin());
 
   addCellsVector(newLine);
 }
@@ -537,7 +538,7 @@ void* CompactHistoryBlock::allocate ( si
 {
  Q_ASSERT ( length > 0 );
   if ( tail-blockStart+length > blockLength )
-    return NULL;
+    return nullptr;
 
   void* block = tail;
   tail += length;
@@ -628,9 +629,9 @@ CompactHistoryLine::CompactHistoryLine (
 
     //kDebug() << "number of different formats in string: " << formatLength;
     formatArray = (CharacterFormat*) blockList.allocate(sizeof(CharacterFormat)*formatLength);
-    Q_ASSERT (formatArray!=NULL);
+    Q_ASSERT (formatArray!=nullptr);
     text = (quint16*) blockList.allocate(sizeof(quint16)*line.size());
-    Q_ASSERT (text!=NULL);
+    Q_ASSERT (text!=nullptr);
 
     length=line.size();
     wrapped=false;
@@ -729,7 +730,7 @@ void CompactHistoryScroll::addCellsVecto
 void CompactHistoryScroll::addCells ( const Character a[], int count )
 {
   TextLine newLine ( count );
-  qCopy ( a,a+count,newLine.begin() );
+  std::copy ( a,a+count,newLine.begin() );
   addCellsVector ( newLine );
 }
 
@@ -923,7 +924,7 @@ HistoryScroll* HistoryTypeFile::scroll(H
   HistoryScroll *newScroll = new HistoryScrollFile(m_fileName);
 
   Character line[LINE_SIZE];
-  int lines = (old != 0) ? old->getLines() : 0;
+  int lines = (old != nullptr) ? old->getLines() : 0;
   for(int i = 0; i < lines; i++)
   {
      int size = old->getLineLen(i);
diff -pruN 0.14.1-3/lib/History.h 0.15.0-0ubuntu1/lib/History.h
--- 0.14.1-3/lib/History.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/History.h	2020-04-24 03:22:14.000000000 +0000
@@ -139,15 +139,15 @@ class HistoryScrollFile : public History
 {
 public:
   HistoryScrollFile(const QString &logFileName);
-  virtual ~HistoryScrollFile();
+  ~HistoryScrollFile() override;
 
-  virtual int  getLines();
-  virtual int  getLineLen(int lineno);
-  virtual void getCells(int lineno, int colno, int count, Character res[]);
-  virtual bool isWrappedLine(int lineno);
+  int  getLines() override;
+  int  getLineLen(int lineno) override;
+  void getCells(int lineno, int colno, int count, Character res[]) override;
+  bool isWrappedLine(int lineno) override;
 
-  virtual void addCells(const Character a[], int count);
-  virtual void addLine(bool previousWrapped=false);
+  void addCells(const Character a[], int count) override;
+  void addLine(bool previousWrapped=false) override;
 
 private:
   int startOfLine(int lineno);
@@ -168,16 +168,16 @@ public:
   typedef QVector<Character> HistoryLine;
 
   HistoryScrollBuffer(unsigned int maxNbLines = 1000);
-  virtual ~HistoryScrollBuffer();
-
-  virtual int  getLines();
-  virtual int  getLineLen(int lineno);
-  virtual void getCells(int lineno, int colno, int count, Character res[]);
-  virtual bool isWrappedLine(int lineno);
+  ~HistoryScrollBuffer() override;
 
-  virtual void addCells(const Character a[], int count);
-  virtual void addCellsVector(const QVector<Character>& cells);
-  virtual void addLine(bool previousWrapped=false);
+  int  getLines() override;
+  int  getLineLen(int lineno) override;
+  void getCells(int lineno, int colno, int count, Character res[]) override;
+  bool isWrappedLine(int lineno) override;
+
+  void addCells(const Character a[], int count) override;
+  void addCellsVector(const QVector<Character>& cells) override;
+  void addLine(bool previousWrapped=false) override;
 
   void setMaxNbLines(unsigned int nbLines);
   unsigned int maxNbLines() const { return _maxLineCount; }
@@ -223,17 +223,17 @@ class HistoryScrollNone : public History
 {
 public:
   HistoryScrollNone();
-  virtual ~HistoryScrollNone();
+  ~HistoryScrollNone() override;
 
-  virtual bool hasScroll();
+  bool hasScroll() override;
 
-  virtual int  getLines();
-  virtual int  getLineLen(int lineno);
-  virtual void getCells(int lineno, int colno, int count, Character res[]);
-  virtual bool isWrappedLine(int lineno);
+  int  getLines() override;
+  int  getLineLen(int lineno) override;
+  void getCells(int lineno, int colno, int count, Character res[]) override;
+  bool isWrappedLine(int lineno) override;
 
-  virtual void addCells(const Character a[], int count);
-  virtual void addLine(bool previousWrapped=false);
+  void addCells(const Character a[], int count) override;
+  void addLine(bool previousWrapped=false) override;
 };
 
 //////////////////////////////////////////////////////////////////////
@@ -243,15 +243,15 @@ class HistoryScrollBlockArray : public H
 {
 public:
   HistoryScrollBlockArray(size_t size);
-  virtual ~HistoryScrollBlockArray();
+  ~HistoryScrollBlockArray() override;
 
-  virtual int  getLines();
-  virtual int  getLineLen(int lineno);
-  virtual void getCells(int lineno, int colno, int count, Character res[]);
-  virtual bool isWrappedLine(int lineno);
+  int  getLines() override;
+  int  getLineLen(int lineno) override;
+  void getCells(int lineno, int colno, int count, Character res[]) override;
+  bool isWrappedLine(int lineno) override;
 
-  virtual void addCells(const Character a[], int count);
-  virtual void addLine(bool previousWrapped=false);
+  void addCells(const Character a[], int count) override;
+  void addLine(bool previousWrapped=false) override;
 
 protected:
   BlockArray m_blockArray;
@@ -293,7 +293,7 @@ public:
 
   CompactHistoryBlock(){
     blockLength = 4096*64; // 256kb
-    head = (quint8*) mmap(0, blockLength, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANON, -1, 0);
+    head = (quint8*) mmap(nullptr, blockLength, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANON, -1, 0);
     //head = (quint8*) malloc(blockLength);
     Q_ASSERT(head != MAP_FAILED);
     tail = blockStart = head;
@@ -363,16 +363,16 @@ class CompactHistoryScroll : public Hist
 
 public:
   CompactHistoryScroll(unsigned int maxNbLines = 1000);
-  virtual ~CompactHistoryScroll();
-
-  virtual int  getLines();
-  virtual int  getLineLen(int lineno);
-  virtual void getCells(int lineno, int colno, int count, Character res[]);
-  virtual bool isWrappedLine(int lineno);
+  ~CompactHistoryScroll() override;
 
-  virtual void addCells(const Character a[], int count);
-  virtual void addCellsVector(const TextLine& cells);
-  virtual void addLine(bool previousWrapped=false);
+  int  getLines() override;
+  int  getLineLen(int lineno) override;
+  void getCells(int lineno, int colno, int count, Character res[]) override;
+  bool isWrappedLine(int lineno) override;
+
+  void addCells(const Character a[], int count) override;
+  void addCellsVector(const TextLine& cells) override;
+  void addLine(bool previousWrapped=false) override;
 
   void setMaxNbLines(unsigned int nbLines);
   unsigned int maxNbLines() const { return _maxLineCount; }
@@ -418,10 +418,10 @@ class HistoryTypeNone : public HistoryTy
 public:
   HistoryTypeNone();
 
-  virtual bool isEnabled() const;
-  virtual int maximumLineCount() const;
+  bool isEnabled() const override;
+  int maximumLineCount() const override;
 
-  virtual HistoryScroll* scroll(HistoryScroll *) const;
+  HistoryScroll* scroll(HistoryScroll *) const override;
 };
 
 class HistoryTypeBlockArray : public HistoryType
@@ -429,10 +429,10 @@ class HistoryTypeBlockArray : public His
 public:
   HistoryTypeBlockArray(size_t size);
 
-  virtual bool isEnabled() const;
-  virtual int maximumLineCount() const;
+  bool isEnabled() const override;
+  int maximumLineCount() const override;
 
-  virtual HistoryScroll* scroll(HistoryScroll *) const;
+  HistoryScroll* scroll(HistoryScroll *) const override;
 
 protected:
   size_t m_size;
@@ -444,11 +444,11 @@ class HistoryTypeFile : public HistoryTy
 public:
   HistoryTypeFile(const QString& fileName=QString());
 
-  virtual bool isEnabled() const;
+  bool isEnabled() const override;
   virtual const QString& getFileName() const;
-  virtual int maximumLineCount() const;
+  int maximumLineCount() const override;
 
-  virtual HistoryScroll* scroll(HistoryScroll *) const;
+  HistoryScroll* scroll(HistoryScroll *) const override;
 
 protected:
   QString m_fileName;
@@ -462,10 +462,10 @@ class HistoryTypeBuffer : public History
 public:
   HistoryTypeBuffer(unsigned int nbLines);
 
-  virtual bool isEnabled() const;
-  virtual int maximumLineCount() const;
+  bool isEnabled() const override;
+  int maximumLineCount() const override;
 
-  virtual HistoryScroll* scroll(HistoryScroll *) const;
+  HistoryScroll* scroll(HistoryScroll *) const override;
 
 protected:
   unsigned int m_nbLines;
@@ -476,10 +476,10 @@ class CompactHistoryType : public Histor
 public:
   CompactHistoryType(unsigned int size);
 
-  virtual bool isEnabled() const;
-  virtual int maximumLineCount() const;
+  bool isEnabled() const override;
+  int maximumLineCount() const override;
 
-  virtual HistoryScroll* scroll(HistoryScroll *) const;
+  HistoryScroll* scroll(HistoryScroll *) const override;
 
 protected:
   unsigned int m_nbLines;
diff -pruN 0.14.1-3/lib/HistorySearch.h 0.15.0-0ubuntu1/lib/HistorySearch.h
--- 0.14.1-3/lib/HistorySearch.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/HistorySearch.h	2020-04-24 03:22:14.000000000 +0000
@@ -41,7 +41,7 @@ public:
     explicit HistorySearch(EmulationPtr emulation, QRegExp regExp, bool forwards,
                            int startColumn, int startLine, QObject* parent);
 
-    ~HistorySearch();
+    ~HistorySearch() override;
 
     void search();
 
diff -pruN 0.14.1-3/lib/kb-layouts/default.keytab 0.15.0-0ubuntu1/lib/kb-layouts/default.keytab
--- 0.14.1-3/lib/kb-layouts/default.keytab	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kb-layouts/default.keytab	2020-04-24 03:22:14.000000000 +0000
@@ -114,6 +114,9 @@ key Delete        +KeyPad : "\E[3~"
 key PgUp    -Shift+KeyPad : "\E[5~"
 key PgDown  -Shift+KeyPad : "\E[6~"
 
+key Clear -AnyMod+KeyPad+AppKeyPad : "\E[OE"
+key Clear +AnyMod+KeyPad+AppKeyPad : "\E[1;*E"
+
 # other grey PC keys
 
 key Enter+NewLine : "\r\n"
@@ -178,4 +181,3 @@ key PgDown  +Shift-AppScreen : scrollPag
 key End     +Shift-AppScreen : scrollDownToBottom
 
 key ScrollLock     : scrollLock
-
diff -pruN 0.14.1-3/lib/KeyboardTranslator.cpp 0.15.0-0ubuntu1/lib/KeyboardTranslator.cpp
--- 0.14.1-3/lib/KeyboardTranslator.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/KeyboardTranslator.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -23,8 +23,8 @@
 #include "KeyboardTranslator.h"
 
 // System
-#include <ctype.h>
-#include <stdio.h>
+#include <cctype>
+#include <cstdio>
 
 // Qt
 #include <QBuffer>
@@ -50,6 +50,13 @@ const QByteArray KeyboardTranslatorManag
 "key Tab : \"\\t\""
 );
 
+#ifdef Q_OS_MAC
+// On Mac, Qt::ControlModifier means Cmd, and MetaModifier means Ctrl
+const Qt::KeyboardModifier KeyboardTranslator::CTRL_MOD = Qt::MetaModifier;
+#else
+const Qt::KeyboardModifier KeyboardTranslator::CTRL_MOD = Qt::ControlModifier;
+#endif
+
 KeyboardTranslatorManager::KeyboardTranslatorManager()
     : _haveLoadedAll(false)
 {
@@ -102,7 +109,7 @@ const KeyboardTranslator* KeyboardTransl
 
     KeyboardTranslator* translator = loadTranslator(name);
 
-    if ( translator != 0 )
+    if ( translator != nullptr )
         _translators[name] = translator;
     else if ( !name.isEmpty() )
         qDebug() << "Unable to load translator" << name;
@@ -148,7 +155,7 @@ KeyboardTranslator* KeyboardTranslatorMa
 
     QFile source(path);
     if (name.isEmpty() || !source.open(QIODevice::ReadOnly | QIODevice::Text))
-        return 0;
+        return nullptr;
 
     return loadTranslator(&source,name);
 }
@@ -185,7 +192,7 @@ KeyboardTranslator* KeyboardTranslatorMa
     else
     {
         delete translator;
-        return 0;
+        return nullptr;
     }
 }
 
@@ -613,6 +620,11 @@ bool KeyboardTranslator::Entry::matches(
                                         Qt::KeyboardModifiers modifiers,
                                         States testState) const
 {
+#ifdef Q_OS_MAC
+    // On Mac, arrow keys are considered part of keypad. Ignore that.
+    modifiers &= ~Qt::KeypadModifier;
+#endif
+
     if ( _keyCode != keyCode )
         return false;
 
@@ -620,7 +632,7 @@ bool KeyboardTranslator::Entry::matches(
         return false;
 
     // if modifiers is non-zero, the 'any modifier' state is implicit
-    if ( modifiers != 0 )
+    if ( (modifiers & ~Qt::KeypadModifier) != 0 )
         testState |= AnyModifierState;
 
     if ( (testState & _stateMask) != (_state & _stateMask) )
diff -pruN 0.14.1-3/lib/KeyboardTranslator.h 0.15.0-0ubuntu1/lib/KeyboardTranslator.h
--- 0.14.1-3/lib/KeyboardTranslator.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/KeyboardTranslator.h	2020-04-24 03:22:14.000000000 +0000
@@ -314,6 +314,9 @@ public:
     /** Returns a list of all entries in the translator. */
     QList<Entry> entries() const;
 
+    /** The modifier code for the actual Ctrl key on this OS. */
+    static const Qt::KeyboardModifier CTRL_MOD;
+
 private:
 
     QMultiHash<int,Entry> _entries; // entries in this keyboard translation,
@@ -558,8 +561,8 @@ inline QByteArray KeyboardTranslator::En
     {
         int modifierValue = 1;
         modifierValue += oneOrZero(modifiers & Qt::ShiftModifier);
-        modifierValue += oneOrZero(modifiers & Qt::AltModifier)     << 1;
-        modifierValue += oneOrZero(modifiers & Qt::ControlModifier) << 2;
+        modifierValue += oneOrZero(modifiers & Qt::AltModifier) << 1;
+        modifierValue += oneOrZero(modifiers & KeyboardTranslator::CTRL_MOD) << 2;
 
         for (int i=0;i<_text.length();i++)
         {
diff -pruN 0.14.1-3/lib/kprocess.cpp 0.15.0-0ubuntu1/lib/kprocess.cpp
--- 0.14.1-3/lib/kprocess.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kprocess.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -35,7 +35,7 @@
 # include <windows.h>
 #else
 # include <unistd.h>
-# include <errno.h>
+# include <cerrno>
 #endif
 
 #ifndef Q_OS_WIN
diff -pruN 0.14.1-3/lib/kprocess.h 0.15.0-0ubuntu1/lib/kprocess.h
--- 0.14.1-3/lib/kprocess.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kprocess.h	2020-04-24 03:22:14.000000000 +0000
@@ -77,12 +77,12 @@ public:
     /**
      * Constructor
      */
-    explicit KProcess(QObject *parent = 0);
+    explicit KProcess(QObject *parent = nullptr);
 
     /**
      * Destructor
      */
-    virtual ~KProcess();
+    ~KProcess() override;
 
     /**
      * Set how to handle the output channels of the child process.
diff -pruN 0.14.1-3/lib/kpty.cpp 0.15.0-0ubuntu1/lib/kpty.cpp
--- 0.14.1-3/lib/kpty.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kpty.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -27,7 +27,7 @@
 #include <QtDebug>
 
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__DragonFly__)
+#if defined(__FreeBSD__) || defined(__DragonFly__)
 #define HAVE_LOGIN
 #define HAVE_LIBUTIL_H
 #endif
@@ -37,6 +37,12 @@
 #define HAVE_UTIL_H
 #endif
 
+#if defined(__NetBSD__)
+#define HAVE_LOGIN
+#define HAVE_UTIL_H
+#define HAVE_OPENPTY
+#endif
+
 #if defined(__APPLE__)
 #define HAVE_OPENPTY
 #define HAVE_UTIL_H
@@ -70,12 +76,12 @@
 #include <sys/stat.h>
 #include <sys/param.h>
 
-#include <errno.h>
+#include <cerrno>
 #include <fcntl.h>
-#include <time.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
+#include <ctime>
+#include <cstdlib>
+#include <cstdio>
+#include <cstring>
 #include <unistd.h>
 #include <grp.h>
 
@@ -174,14 +180,12 @@ KPtyPrivate::~KPtyPrivate()
 {
 }
 
-#ifndef HAVE_OPENPTY
 bool KPtyPrivate::chownpty(bool)
 {
 //    return !QProcess::execute(KStandardDirs::findExe("kgrantpty"),
 //        QStringList() << (grant?"--grant":"--revoke") << QString::number(masterFd));
     return true;
 }
-#endif
 
 /////////////////////////////
 // public member functions //
@@ -281,8 +285,8 @@ bool KPty::open()
     // Linux device names, FIXME: Trouble on other systems?
     for (const char * s3 = "pqrstuvwxyzabcde"; *s3; s3++) {
         for (const char * s4 = "0123456789abcdef"; *s4; s4++) {
-            ptyName = QString().sprintf("/dev/pty%c%c", *s3, *s4).toUtf8();
-            d->ttyName = QString().sprintf("/dev/tty%c%c", *s3, *s4).toUtf8();
+            ptyName = QByteArrayLiteral("/dev/pty") + *s3 + *s4;
+            d->ttyName = QByteArrayLiteral("/dev/tty") + *s3 + *s4;
 
             d->masterFd = ::open(ptyName.data(), O_RDWR);
             if (d->masterFd >= 0) {
@@ -395,8 +399,12 @@ bool KPty::open(int fd)
 # else
     int ptyno;
     if (!ioctl(fd, TIOCGPTN, &ptyno)) {
-        char buf[32];
-        sprintf(buf, "/dev/pts/%d", ptyno);
+        const size_t sz = 32;
+        char buf[sz];
+        const size_t r = snprintf(buf, sz, "/dev/pts/%d", ptyno);
+        if (sz <= r) {
+            qWarning("KPty::open: Buffer too small\n");
+        }
         d->ttyName = buf;
 # endif
     } else {
@@ -546,7 +554,7 @@ void KPty::login(const char * user, cons
 # ifdef HAVE_UTMPX
     gettimeofday(&l_struct.ut_tv, 0);
 # else
-    l_struct.ut_time = time(0);
+    l_struct.ut_time = time(nullptr);
 # endif
 
 # ifdef HAVE_LOGIN
@@ -648,7 +656,7 @@ void KPty::logout()
     }
     endutxent();
 #  else
-    ut->ut_time = time(0);
+    ut->ut_time = time(nullptr);
     pututline(ut);
 }
 endutent();
diff -pruN 0.14.1-3/lib/kptydevice.cpp 0.15.0-0ubuntu1/lib/kptydevice.cpp
--- 0.14.1-3/lib/kptydevice.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kptydevice.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -35,8 +35,8 @@
 #include <QSocketNotifier>
 
 #include <unistd.h>
-#include <errno.h>
-#include <signal.h>
+#include <cerrno>
+#include <csignal>
 #include <termios.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
@@ -74,7 +74,7 @@ static void qt_ignore_sigpipe()
         struct sigaction noaction;
         memset(&noaction, 0, sizeof(noaction));
         noaction.sa_handler = SIG_IGN;
-        sigaction(SIGPIPE, &noaction, 0);
+        sigaction(SIGPIPE, &noaction, nullptr);
     }
 }
 
@@ -211,7 +211,7 @@ bool KPtyDevicePrivate::doWait(int msecs
     struct timeval tv, *tvp;
 
     if (msecs < 0)
-        tvp = 0;
+        tvp = nullptr;
     else {
         tv.tv_sec = msecs / 1000;
         tv.tv_usec = (msecs % 1000) * 1000;
@@ -243,7 +243,7 @@ bool KPtyDevicePrivate::doWait(int msecs
         }
 #endif
 
-        switch (select(q->masterFd() + 1, &rfds, &wfds, 0, tvp)) {
+        switch (select(q->masterFd() + 1, &rfds, &wfds, nullptr, tvp)) {
         case -1:
             if (errno == EINTR)
                 break;
diff -pruN 0.14.1-3/lib/kptydevice.h 0.15.0-0ubuntu1/lib/kptydevice.h
--- 0.14.1-3/lib/kptydevice.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kptydevice.h	2020-04-24 03:22:14.000000000 +0000
@@ -55,7 +55,7 @@ public:
     /**
      * Constructor
      */
-    KPtyDevice(QObject *parent = 0);
+    KPtyDevice(QObject *parent = nullptr);
 
     /**
      * Destructor:
@@ -63,14 +63,14 @@ public:
      *  If the pty is still open, it will be closed. Note, however, that
      *  an utmp registration is @em not undone.
      */
-    virtual ~KPtyDevice();
+    ~KPtyDevice() override;
 
     /**
      * Create a pty master/slave pair.
      *
      * @return true if a pty pair was successfully opened
      */
-    virtual bool open(OpenMode mode = ReadWrite | Unbuffered);
+    bool open(OpenMode mode = ReadWrite | Unbuffered) override;
 
     /**
      * Open using an existing pty master. The ownership of the fd
@@ -90,7 +90,7 @@ public:
     /**
      * Close the pty master/slave pair.
      */
-    virtual void close();
+    void close() override;
 
     /**
      * Sets whether the KPtyDevice monitors the pty for incoming data.
@@ -119,30 +119,30 @@ public:
     /**
      * @return always true
      */
-    virtual bool isSequential() const;
+    bool isSequential() const override;
 
     /**
      * @reimp
      */
-    bool canReadLine() const;
+    bool canReadLine() const override;
 
     /**
      * @reimp
      */
-    bool atEnd() const;
+    bool atEnd() const override;
 
     /**
      * @reimp
      */
-    qint64 bytesAvailable() const;
+    qint64 bytesAvailable() const override;
 
     /**
      * @reimp
      */
-    qint64 bytesToWrite() const;
+    qint64 bytesToWrite() const override;
 
-    bool waitForBytesWritten(int msecs = -1);
-    bool waitForReadyRead(int msecs = -1);
+    bool waitForBytesWritten(int msecs = -1) override;
+    bool waitForReadyRead(int msecs = -1) override;
 
 
 Q_SIGNALS:
@@ -154,9 +154,9 @@ Q_SIGNALS:
     void readEof();
 
 protected:
-    virtual qint64 readData(char *data, qint64 maxSize);
-    virtual qint64 readLineData(char *data, qint64 maxSize);
-    virtual qint64 writeData(const char *data, qint64 maxSize);
+    qint64 readData(char *data, qint64 maxSize) override;
+    qint64 readLineData(char *data, qint64 maxSize) override;
+    qint64 writeData(const char *data, qint64 maxSize) override;
 
 private:
     Q_PRIVATE_SLOT(d_func(), bool _k_canRead())
@@ -339,7 +339,7 @@ struct KPtyDevicePrivate : public KPtyPr
     KPtyDevicePrivate(KPty* parent) :
         KPtyPrivate(parent),
         emittedReadyRead(false), emittedBytesWritten(false),
-        readNotifier(0), writeNotifier(0)
+        readNotifier(nullptr), writeNotifier(nullptr)
     {
     }
 
diff -pruN 0.14.1-3/lib/kpty.h 0.15.0-0ubuntu1/lib/kpty.h
--- 0.14.1-3/lib/kpty.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kpty.h	2020-04-24 03:22:14.000000000 +0000
@@ -95,7 +95,7 @@ public:
      *  of the client. For local logins from inside an X session it should
      *  be the name of the X display. Otherwise it should be empty.
      */
-    void login(const char * user = 0, const char * remotehost = 0);
+    void login(const char * user = nullptr, const char * remotehost = nullptr);
 
     /**
      * Removes the utmp entry for this tty.
diff -pruN 0.14.1-3/lib/kpty_p.h 0.15.0-0ubuntu1/lib/kpty_p.h
--- 0.14.1-3/lib/kpty_p.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kpty_p.h	2020-04-24 03:22:14.000000000 +0000
@@ -35,9 +35,7 @@ public:
     KPtyPrivate(KPty* parent);
     virtual ~KPtyPrivate();
 
-#ifndef HAVE_OPENPTY
     bool chownpty(bool grant);
-#endif
 
     int masterFd;
     int slaveFd;
diff -pruN 0.14.1-3/lib/kptyprocess.cpp 0.15.0-0ubuntu1/lib/kptyprocess.cpp
--- 0.14.1-3/lib/kptyprocess.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kptyprocess.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -32,9 +32,9 @@
 #include "kprocess.h"
 #include "kptydevice.h"
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <unistd.h>
-#include <signal.h>
+#include <csignal>
 #include <QDebug>
 
 KPtyProcess::KPtyProcess(QObject *parent) :
diff -pruN 0.14.1-3/lib/kptyprocess.h 0.15.0-0ubuntu1/lib/kptyprocess.h
--- 0.14.1-3/lib/kptyprocess.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/kptyprocess.h	2020-04-24 03:22:14.000000000 +0000
@@ -33,7 +33,7 @@
 #include "kprocess.h"
 #include "kptydevice.h"
 
-#include <signal.h>
+#include <csignal>
 
 class KPtyDevice;
 
@@ -74,7 +74,7 @@ public:
     /**
      * Constructor
      */
-    explicit KPtyProcess(QObject *parent = 0);
+    explicit KPtyProcess(QObject *parent = nullptr);
 
     /**
      * Construct a process using an open pty master.
@@ -83,12 +83,12 @@ public:
      *   The process does not take ownership of the descriptor;
      *   it will not be automatically closed at any point.
      */
-    KPtyProcess(int ptyMasterFd, QObject *parent = 0);
+    KPtyProcess(int ptyMasterFd, QObject *parent = nullptr);
 
     /**
      * Destructor
      */
-    virtual ~KPtyProcess();
+    ~KPtyProcess() override;
 
     /**
      * Set to which channels the PTY should be assigned.
@@ -144,7 +144,7 @@ protected:
     /**
      * @reimp
      */
-    virtual void setupChildProcess();
+    void setupChildProcess() override;
 
 private:
     Q_PRIVATE_SLOT(d_func(), void _k_onStateChanged(QProcess::ProcessState))
diff -pruN 0.14.1-3/lib/Pty.cpp 0.15.0-0ubuntu1/lib/Pty.cpp
--- 0.14.1-3/lib/Pty.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Pty.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -33,9 +33,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <errno.h>
+#include <cerrno>
 #include <termios.h>
-#include <signal.h>
+#include <csignal>
 
 // Qt
 #include <QStringList>
@@ -56,7 +56,7 @@ void Pty::setWindowSize(int lines, int c
 }
 QSize Pty::windowSize() const
 {
-    return QSize(_windowColumns,_windowLines);
+    return {_windowColumns,_windowLines};
 }
 
 void Pty::setFlowControlEnabled(bool enable)
@@ -173,6 +173,7 @@ int Pty::start(const QString& program,
   addEnvironmentVariables(environment);
 
   setEnv(QLatin1String("WINDOWID"), QString::number(winid));
+  setEnv(QLatin1String("COLORTERM"), QLatin1String("truecolor"));
 
   // unless the LANGUAGE environment variable has been set explicitly
   // set it to a null string
@@ -328,11 +329,12 @@ void Pty::setupChildProcess()
     struct sigaction action;
     sigset_t sigset;
     sigemptyset(&action.sa_mask);
+    sigemptyset(&sigset);
     action.sa_handler = SIG_DFL;
     action.sa_flags = 0;
     for (int signal=1;signal < NSIG; signal++) {
-        sigaction(signal,&action,0L);
+        sigaction(signal,&action,nullptr);
         sigaddset(&sigset, signal);
     }
-    sigprocmask(SIG_UNBLOCK, &sigset, NULL);
+    sigprocmask(SIG_UNBLOCK, &sigset, nullptr);
 }
diff -pruN 0.14.1-3/lib/Pty.h 0.15.0-0ubuntu1/lib/Pty.h
--- 0.14.1-3/lib/Pty.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Pty.h	2020-04-24 03:22:14.000000000 +0000
@@ -70,15 +70,15 @@ Q_OBJECT
      * To start the terminal process, call the run() method with the
      * name of the program to start and appropriate arguments.
      */
-    explicit Pty(QObject* parent = 0);
+    explicit Pty(QObject* parent = nullptr);
 
     /**
      * Construct a process using an open pty master.
      * See KPtyProcess::KPtyProcess()
      */
-    explicit Pty(int ptyMasterFd, QObject* parent = 0);
+    explicit Pty(int ptyMasterFd, QObject* parent = nullptr);
 
-    ~Pty();
+    ~Pty() override;
 
     /**
      * Starts the terminal process.
@@ -189,7 +189,7 @@ Q_OBJECT
     void receivedData(const char* buffer, int length);
 
   protected:
-      void setupChildProcess();
+      void setupChildProcess() override;
 
   private slots:
     // called when data is received from the terminal process
diff -pruN 0.14.1-3/lib/qtermwidget.cpp 0.15.0-0ubuntu1/lib/qtermwidget.cpp
--- 0.14.1-3/lib/qtermwidget.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/qtermwidget.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -33,6 +33,12 @@
 #include "SearchBar.h"
 #include "qtermwidget.h"
 
+#ifdef Q_OS_MACOS
+// Qt does not support fontconfig on macOS, so we need to use a "real" font name.
+#define DEFAULT_FONT_FAMILY                   "Menlo"
+#else
+#define DEFAULT_FONT_FAMILY                   "Monospace"
+#endif
 
 #define STEP_ZOOM 1
 
@@ -43,8 +49,10 @@ void *createTermWidget(int startnow, voi
     return (void*) new QTermWidget(startnow, (QWidget*)parent);
 }
 
-struct TermWidgetImpl {
-    TermWidgetImpl(QWidget* parent = 0);
+class TermWidgetImpl {
+
+public:
+    TermWidgetImpl(QWidget* parent = nullptr);
 
     TerminalDisplay *m_terminalDisplay;
     Session *m_session;
@@ -156,8 +164,8 @@ void QTermWidget::search(bool forwards,
         m_impl->m_terminalDisplay->screenWindow()->screen()->getSelectionStart(startColumn, startLine);
     }
 
-    qDebug() << "current selection starts at: " << startColumn << startLine;
-    qDebug() << "current cursor position: " << m_impl->m_terminalDisplay->screenWindow()->cursorPosition();
+    //qDebug() << "current selection starts at: " << startColumn << startLine;
+    //qDebug() << "current cursor position: " << m_impl->m_terminalDisplay->screenWindow()->cursorPosition();
 
     QRegExp regExp(m_searchBar->searchText());
     regExp.setPatternSyntax(m_searchBar->useRegularExpression() ? QRegExp::RegExp : QRegExp::FixedString);
@@ -175,7 +183,7 @@ void QTermWidget::search(bool forwards,
 void QTermWidget::matchFound(int startColumn, int startLine, int endColumn, int endLine)
 {
     ScreenWindow* sw = m_impl->m_terminalDisplay->screenWindow();
-    qDebug() << "Scroll to" << startLine;
+    //qDebug() << "Scroll to" << startLine;
     sw->scrollTo(startLine);
     sw->setTrackOutput(false);
     sw->notifyOutputChanged();
@@ -268,11 +276,11 @@ void QTermWidget::init(int startnow)
 
     m_translator = new QTranslator(this);
 
-    for (const QString& dir : dirs) {
-        qDebug() << "Trying to load translation file from dir" << dir;
+    for (const QString& dir : qAsConst(dirs)) {
+        //qDebug() << "Trying to load translation file from dir" << dir;
         if (m_translator->load(QLocale::system(), QLatin1String("qtermwidget"), QLatin1String(QLatin1String("_")), dir)) {
             qApp->installTranslator(m_translator);
-            qDebug() << "Translations found in" << dir;
+            //qDebug() << "Translations found in" << dir;
             break;
         }
     }
@@ -321,7 +329,7 @@ void QTermWidget::init(int startnow)
 //    m_impl->m_terminalDisplay->setSize(80, 40);
 
     QFont font = QApplication::font();
-    font.setFamily(QLatin1String("Monospace"));
+    font.setFamily(QLatin1String(DEFAULT_FONT_FAMILY));
     font.setPointSize(10);
     font.setStyleHint(QFont::TypeWriter);
     setTerminalFont(font);
@@ -419,7 +427,7 @@ void QTermWidget::setTextCodec(QTextCode
 
 void QTermWidget::setColorScheme(const QString& origName)
 {
-    const ColorScheme *cs = 0;
+    const ColorScheme *cs = nullptr;
 
     const bool isFile = QFile::exists(origName);
     const QString& name = isFile ?
@@ -499,6 +507,11 @@ void QTermWidget::sendText(const QString
     m_impl->m_session->sendText(text);
 }
 
+void QTermWidget::sendKeyEvent(QKeyEvent *e)
+{
+    m_impl->m_session->sendKeyEvent(e);
+}
+
 void QTermWidget::resizeEvent(QResizeEvent*)
 {
 //qDebug("global window resizing...with %d %d", this->size().width(), this->size().height());
@@ -743,3 +756,16 @@ int QTermWidget::getMargin() const
 {
     return m_impl->m_terminalDisplay->margin();
 }
+
+void QTermWidget::saveHistory(QIODevice *device)
+{
+    QTextStream stream(device);
+    PlainTextDecoder decoder;
+    decoder.begin(&stream);
+    m_impl->m_session->emulation()->writeToStream(&decoder, 0, m_impl->m_session->emulation()->lineCount());
+}
+
+void QTermWidget::setDrawLineChars(bool drawLineChars)
+{
+    m_impl->m_terminalDisplay->setDrawLineChars(drawLineChars);
+}
diff -pruN 0.14.1-3/lib/qtermwidget.h 0.15.0-0ubuntu1/lib/qtermwidget.h
--- 0.14.1-3/lib/qtermwidget.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/qtermwidget.h	2020-04-24 03:22:14.000000000 +0000
@@ -25,9 +25,10 @@
 #include "Emulation.h"
 #include "Filter.h"
 #include "qtermwidget_export.h"
+#include "qtermwidget_version.h"
 
 class QVBoxLayout;
-struct TermWidgetImpl;
+class TermWidgetImpl;
 class SearchBar;
 class QUrl;
 
@@ -51,14 +52,14 @@ public:
 
     //Creation of widget
     QTermWidget(int startnow, // 1 = start shell programm immediatelly
-                QWidget * parent = 0);
+                QWidget * parent = nullptr);
     // A dummy constructor for Qt Designer. startnow is 1 by default
-    QTermWidget(QWidget *parent = 0);
+    QTermWidget(QWidget *parent = nullptr);
 
-    virtual ~QTermWidget();
+    ~QTermWidget() override;
 
     //Initial size
-    QSize sizeHint() const;
+    QSize sizeHint() const override;
 
     // expose TerminalDisplay::TerminalSizeHint, setTerminalSizeHint
     void setTerminalSizeHint(bool on);
@@ -125,6 +126,9 @@ public:
     // Send some text to terminal
     void sendText(const QString & text);
 
+    // Send key event to terminal
+    void sendKeyEvent(QKeyEvent* e);
+
     // Sets whether flow control is enabled
     void setFlowControlEnabled(bool enabled);
 
@@ -227,6 +231,8 @@ public:
 
     /** Get the empty space outside the terminal */
     int getMargin() const;
+
+    void setDrawLineChars(bool drawLineChars);
 signals:
     void finished();
     void copyAvailable(bool);
@@ -287,8 +293,9 @@ public slots:
 
     void toggleShowSearchBar();
 
+    void saveHistory(QIODevice *device);
 protected:
-    virtual void resizeEvent(QResizeEvent *);
+    void resizeEvent(QResizeEvent *) override;
 
 protected slots:
     void sessionFinished();
diff -pruN 0.14.1-3/lib/qtermwidget_version.h.in 0.15.0-0ubuntu1/lib/qtermwidget_version.h.in
--- 0.14.1-3/lib/qtermwidget_version.h.in	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/qtermwidget_version.h.in	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,33 @@
+/*  Copyright (C) 2020 Axel Kittenberger (axel.kittenberger@univie.ac.at)
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
+
+
+#ifndef _Q_TERM_WIDGET_VERSION
+#define _Q_TERM_WIDGET_VERSION
+
+#include <QtGlobal>
+#define QTERMWIDGET_VERSION_MAJOR @QTERMWIDGET_VERSION_MAJOR@
+#define QTERMWIDGET_VERSION_MINOR @QTERMWIDGET_VERSION_MINOR@
+#define QTERMWIDGET_VERSION_PATCH @QTERMWIDGET_VERSION_PATCH@
+#define QTERMWIDGET_VERSION QT_VERSION_CHECK(\
+	QTERMWIDGET_VERSION_MAJOR,\
+	QTERMWIDGET_VERSION_MINOR,\
+	QTERMWIDGET_VERSION_PATCH)
+
+#endif
+
diff -pruN 0.14.1-3/lib/Screen.cpp 0.15.0-0ubuntu1/lib/Screen.cpp
--- 0.14.1-3/lib/Screen.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Screen.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -24,11 +24,11 @@
 #include "Screen.h"
 
 // Standard
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
 #include <unistd.h>
-#include <string.h>
-#include <ctype.h>
+#include <cstring>
+#include <cctype>
 
 // Qt
 #include <QTextStream>
@@ -1359,7 +1359,7 @@ void Screen::setScroll(const HistoryType
     else
     {
         HistoryScroll* oldScroll = history;
-        history = t.scroll(0);
+        history = t.scroll(nullptr);
         delete oldScroll;
     }
 }
diff -pruN 0.14.1-3/lib/Screen.h 0.15.0-0ubuntu1/lib/Screen.h
--- 0.14.1-3/lib/Screen.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Screen.h	2020-04-24 03:22:14.000000000 +0000
@@ -637,8 +637,8 @@ private:
     int _bottomMargin;
 
     // states ----------------
-    int currentModes[MODES_SCREEN];
-    int savedModes[MODES_SCREEN];
+    bool currentModes[MODES_SCREEN];
+    bool savedModes[MODES_SCREEN];
 
     // ----------------------------
 
diff -pruN 0.14.1-3/lib/ScreenWindow.cpp 0.15.0-0ubuntu1/lib/ScreenWindow.cpp
--- 0.14.1-3/lib/ScreenWindow.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/ScreenWindow.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -30,7 +30,7 @@ using namespace Konsole;
 
 ScreenWindow::ScreenWindow(QObject* parent)
     : QObject(parent)
-    , _windowBuffer(0)
+    , _windowBuffer(nullptr)
     , _windowBufferSize(0)
     , _bufferNeedsUpdate(true)
     , _windowLines(1)
@@ -59,7 +59,7 @@ Character* ScreenWindow::getImage()
 {
     // reallocate internal buffer if the window size has changed
     int size = windowLines() * windowColumns();
-    if (_windowBuffer == 0 || _windowBufferSize != size)
+    if (_windowBuffer == nullptr || _windowBufferSize != size)
     {
         delete[] _windowBuffer;
         _windowBufferSize = size;
@@ -259,7 +259,7 @@ QRect ScreenWindow::scrollRegion() const
     if ( atEndOfOutput() && equalToScreenSize )
         return _screen->lastScrolledRegion();
     else
-        return QRect(0,0,windowColumns(),windowLines());
+        return {0,0,windowColumns(),windowLines()};
 }
 
 void ScreenWindow::notifyOutputChanged()
diff -pruN 0.14.1-3/lib/ScreenWindow.h 0.15.0-0ubuntu1/lib/ScreenWindow.h
--- 0.14.1-3/lib/ScreenWindow.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/ScreenWindow.h	2020-04-24 03:22:14.000000000 +0000
@@ -64,8 +64,8 @@ public:
      * to notify the window when the associated screen has changed and synchronize selection updates
      * between all views on a session.
      */
-    ScreenWindow(QObject* parent = 0);
-    virtual ~ScreenWindow();
+    ScreenWindow(QObject* parent = nullptr);
+    ~ScreenWindow() override;
 
     /** Sets the screen which this window looks onto */
     void setScreen(Screen* screen);
diff -pruN 0.14.1-3/lib/SearchBar.cpp 0.15.0-0ubuntu1/lib/SearchBar.cpp
--- 0.14.1-3/lib/SearchBar.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/SearchBar.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -81,6 +81,7 @@ void SearchBar::show()
 {
     QWidget::show();
     widget.searchTextEdit->setFocus();
+    widget.searchTextEdit->selectAll();
 }
 
 void SearchBar::noMatchFound()
@@ -112,8 +113,6 @@ void SearchBar::keyReleaseEvent(QKeyEven
 
 void SearchBar::clearBackgroundColor()
 {
-    QPalette p;
-    p.setColor(QPalette::Base, Qt::white);
-    widget.searchTextEdit->setPalette(p);
+    widget.searchTextEdit->setPalette(QWidget::window()->palette());
 
 }
diff -pruN 0.14.1-3/lib/SearchBar.h 0.15.0-0ubuntu1/lib/SearchBar.h
--- 0.14.1-3/lib/SearchBar.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/SearchBar.h	2020-04-24 03:22:14.000000000 +0000
@@ -27,8 +27,8 @@
 class SearchBar : public QWidget {
     Q_OBJECT
 public:
-    SearchBar(QWidget* parent = 0);
-    virtual ~SearchBar();
+    SearchBar(QWidget* parent = nullptr);
+    ~SearchBar() override;
     virtual void show();
     QString searchText();
     bool useRegularExpression();
@@ -45,7 +45,7 @@ signals:
     void findPrevious();
 
 protected:
-    virtual void keyReleaseEvent(QKeyEvent* keyEvent);
+    void keyReleaseEvent(QKeyEvent* keyEvent) override;
 
 private slots:
     void clearBackgroundColor();
diff -pruN 0.14.1-3/lib/Session.cpp 0.15.0-0ubuntu1/lib/Session.cpp
--- 0.14.1-3/lib/Session.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Session.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -26,7 +26,7 @@
 #include "Session.h"
 
 // Standard
-#include <stdlib.h>
+#include <cstdlib>
 
 // Qt
 #include <QApplication>
@@ -50,8 +50,8 @@ int Session::lastSessionId = 0;
 
 Session::Session(QObject* parent) :
     QObject(parent),
-        _shellProcess(0)
-        , _emulation(0)
+        _shellProcess(nullptr)
+        , _emulation(nullptr)
         , _monitorActivity(false)
         , _monitorSilence(false)
         , _notifiedActivity(false)
@@ -172,7 +172,7 @@ void Session::addView(TerminalDisplay *
 
     _views.append(widget);
 
-    if ( _emulation != 0 ) {
+    if ( _emulation != nullptr ) {
         // connect emulation - view signals and slots
         connect( widget , SIGNAL(keyPressedSignal(QKeyEvent *)) , _emulation ,
                  SLOT(sendKeyEvent(QKeyEvent *)) );
@@ -220,19 +220,19 @@ void Session::removeView(TerminalDisplay
 {
     _views.removeAll(widget);
 
-    disconnect(widget,0,this,0);
+    disconnect(widget,nullptr,this,nullptr);
 
-    if ( _emulation != 0 ) {
+    if ( _emulation != nullptr ) {
         // disconnect
         //  - key presses signals from widget
         //  - mouse activity signals from widget
         //  - string sending signals from widget
         //
         //  ... and any other signals connected in addView()
-        disconnect( widget, 0, _emulation, 0);
+        disconnect( widget, nullptr, _emulation, nullptr);
 
         // disconnect state change signals emitted by emulation
-        disconnect( _emulation , 0 , widget , 0);
+        disconnect( _emulation , nullptr , widget , nullptr);
     }
 
     // close the session automatically when the last view is removed
@@ -451,10 +451,7 @@ void Session::monitorTimerDone()
 void Session::activityStateSet(int state)
 {
     if (state==NOTIFYBELL) {
-        QString s;
-        s.sprintf("Bell in session '%s'",_nameTitle.toUtf8().data());
-
-        emit bellRequest( s );
+        emit bellRequest(tr("Bell in session '%1'").arg(_nameTitle));
     } else if (state==NOTIFYACTIVITY) {
         if (_monitorSilence) {
             _monitorTimer->start(_silenceSeconds*1000);
@@ -568,6 +565,11 @@ void Session::sendText(const QString & t
     _emulation->sendText(text);
 }
 
+void Session::sendKeyEvent(QKeyEvent* e) const
+{
+    _emulation->sendKeyEvent(e);
+}
+
 Session::~Session()
 {
     delete _emulation;
@@ -593,21 +595,22 @@ void Session::done(int exitStatus)
         return;
     }
 
+    // message is not being used. But in the original kpty.cpp file
+    // (https://cgit.kde.org/kpty.git/) it's part of a notification.
+    // So, we make it translatable, hoping that in the future it will
+    // be used in some kind of notification.
     QString message;
     if (!_wantedClose || exitStatus != 0) {
 
         if (_shellProcess->exitStatus() == QProcess::NormalExit) {
-            message.sprintf("Session '%s' exited with status %d.",
-                          _nameTitle.toUtf8().data(), exitStatus);
+            message = tr("Session '%1' exited with status %2.").arg(_nameTitle).arg(exitStatus);
         } else {
-            message.sprintf("Session '%s' crashed.",
-                          _nameTitle.toUtf8().data());
+            message = tr("Session '%1' crashed.").arg(_nameTitle);
         }
     }
 
     if ( !_wantedClose && _shellProcess->exitStatus() != QProcess::NormalExit )
-        message.sprintf("Session '%s' exited unexpectedly.",
-                        _nameTitle.toUtf8().data());
+        message = tr("Session '%1' exited unexpectedly.").arg(_nameTitle);
     else
         emit finished();
 
@@ -1013,8 +1016,7 @@ void SessionGroup::setMasterStatus(Sessi
     bool wasMaster = _sessions[session];
     _sessions[session] = master;
 
-    if ((!wasMaster && !master)
-            || (wasMaster && master)) {
+    if (wasMaster == master) {
         return;
     }
 
diff -pruN 0.14.1-3/lib/Session.h 0.15.0-0ubuntu1/lib/Session.h
--- 0.14.1-3/lib/Session.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Session.h	2020-04-24 03:22:14.000000000 +0000
@@ -71,8 +71,8 @@ public:
      * falls back to using the program specified in the SHELL environment
      * variable.
      */
-    Session(QObject* parent = 0);
-    virtual ~Session();
+    Session(QObject* parent = nullptr);
+    ~Session() override;
 
     /**
      * Returns true if the session is currently running.  This will be true
@@ -314,6 +314,8 @@ public:
      */
     void sendText(const QString & text) const;
 
+    void sendKeyEvent(QKeyEvent* e) const;
+
     /**
      * Returns the process id of the terminal process.
      * This is the id used by the system API to refer to the process.
@@ -583,7 +585,7 @@ public:
     /** Constructs an empty session group. */
     SessionGroup();
     /** Destroys the session group and removes all connections between master and slave sessions. */
-    ~SessionGroup();
+    ~SessionGroup() override;
 
     /** Adds a session to the group. */
     void addSession( Session * session );
diff -pruN 0.14.1-3/lib/TerminalCharacterDecoder.cpp 0.15.0-0ubuntu1/lib/TerminalCharacterDecoder.cpp
--- 0.14.1-3/lib/TerminalCharacterDecoder.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/TerminalCharacterDecoder.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -31,9 +31,11 @@
 // Konsole
 #include "konsole_wcwidth.h"
 
+#include <cwctype>
+
 using namespace Konsole;
 PlainTextDecoder::PlainTextDecoder()
- : _output(0)
+ : _output(nullptr)
  , _includeTrailingWhitespace(true)
  , _recordLinePositions(false)
 {
@@ -55,7 +57,7 @@ void PlainTextDecoder::begin(QTextStream
 }
 void PlainTextDecoder::end()
 {
-    _output = 0;
+    _output = nullptr;
 }
 
 void PlainTextDecoder::setRecordLinePositions(bool record)
@@ -109,7 +111,7 @@ void PlainTextDecoder::decodeLine(const
 }
 
 HTMLDecoder::HTMLDecoder() :
-        _output(0)
+        _output(nullptr)
     ,_colorTable(base_color_table)
        ,_innerSpanOpen(false)
        ,_lastRendition(DEFAULT_RENDITION)
@@ -139,7 +141,7 @@ void HTMLDecoder::end()
 
     *_output << QString::fromStdWString(text);
 
-    _output = 0;
+    _output = nullptr;
 
 }
 
diff -pruN 0.14.1-3/lib/TerminalCharacterDecoder.h 0.15.0-0ubuntu1/lib/TerminalCharacterDecoder.h
--- 0.14.1-3/lib/TerminalCharacterDecoder.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/TerminalCharacterDecoder.h	2020-04-24 03:22:14.000000000 +0000
@@ -92,12 +92,12 @@ public:
     /** Enables recording of character positions at which new lines are added.  See linePositions() */
     void setRecordLinePositions(bool record);
 
-    virtual void begin(QTextStream* output);
-    virtual void end();
+    void begin(QTextStream* output) override;
+    void end() override;
 
-    virtual void decodeLine(const Character* const characters,
+    void decodeLine(const Character* const characters,
                             int count,
-                            LineProperty properties);
+                            LineProperty properties) override;
 
 
 private:
@@ -125,12 +125,12 @@ public:
      */
     void setColorTable( const ColorEntry* table );
 
-    virtual void decodeLine(const Character* const characters,
+    void decodeLine(const Character* const characters,
                             int count,
-                            LineProperty properties);
+                            LineProperty properties) override;
 
-    virtual void begin(QTextStream* output);
-    virtual void end();
+    void begin(QTextStream* output) override;
+    void end() override;
 
 private:
     void openSpan(std::wstring& text , const QString& style);
diff -pruN 0.14.1-3/lib/TerminalDisplay.cpp 0.15.0-0ubuntu1/lib/TerminalDisplay.cpp
--- 0.14.1-3/lib/TerminalDisplay.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/TerminalDisplay.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -82,17 +82,17 @@ const ColorEntry Konsole::base_color_tab
 {
   // Fixme: could add faint colors here, also.
   // normal
-  ColorEntry(QColor(0x00,0x00,0x00), 0), ColorEntry( QColor(0xB2,0xB2,0xB2), 1), // Dfore, Dback
-  ColorEntry(QColor(0x00,0x00,0x00), 0), ColorEntry( QColor(0xB2,0x18,0x18), 0), // Black, Red
-  ColorEntry(QColor(0x18,0xB2,0x18), 0), ColorEntry( QColor(0xB2,0x68,0x18), 0), // Green, Yellow
-  ColorEntry(QColor(0x18,0x18,0xB2), 0), ColorEntry( QColor(0xB2,0x18,0xB2), 0), // Blue, Magenta
-  ColorEntry(QColor(0x18,0xB2,0xB2), 0), ColorEntry( QColor(0xB2,0xB2,0xB2), 0), // Cyan, White
+  ColorEntry(QColor(0x00,0x00,0x00), false), ColorEntry( QColor(0xB2,0xB2,0xB2), true), // Dfore, Dback
+  ColorEntry(QColor(0x00,0x00,0x00), false), ColorEntry( QColor(0xB2,0x18,0x18), false), // Black, Red
+  ColorEntry(QColor(0x18,0xB2,0x18), false), ColorEntry( QColor(0xB2,0x68,0x18), false), // Green, Yellow
+  ColorEntry(QColor(0x18,0x18,0xB2), false), ColorEntry( QColor(0xB2,0x18,0xB2), false), // Blue, Magenta
+  ColorEntry(QColor(0x18,0xB2,0xB2), false), ColorEntry( QColor(0xB2,0xB2,0xB2), false), // Cyan, White
   // intensiv
-  ColorEntry(QColor(0x00,0x00,0x00), 0), ColorEntry( QColor(0xFF,0xFF,0xFF), 1),
-  ColorEntry(QColor(0x68,0x68,0x68), 0), ColorEntry( QColor(0xFF,0x54,0x54), 0),
-  ColorEntry(QColor(0x54,0xFF,0x54), 0), ColorEntry( QColor(0xFF,0xFF,0x54), 0),
-  ColorEntry(QColor(0x54,0x54,0xFF), 0), ColorEntry( QColor(0xFF,0x54,0xFF), 0),
-  ColorEntry(QColor(0x54,0xFF,0xFF), 0), ColorEntry( QColor(0xFF,0xFF,0xFF), 0)
+  ColorEntry(QColor(0x00,0x00,0x00), false), ColorEntry( QColor(0xFF,0xFF,0xFF), true),
+  ColorEntry(QColor(0x68,0x68,0x68), false), ColorEntry( QColor(0xFF,0x54,0x54), false),
+  ColorEntry(QColor(0x54,0xFF,0x54), false), ColorEntry( QColor(0xFF,0xFF,0x54), false),
+  ColorEntry(QColor(0x54,0x54,0xFF), false), ColorEntry( QColor(0xFF,0x54,0xFF), false),
+  ColorEntry(QColor(0x54,0xFF,0xFF), false), ColorEntry( QColor(0xFF,0xFF,0xFF), false)
 };
 
 // scroll increment used when dragging selection at top/bottom of window.
@@ -128,7 +128,7 @@ void TerminalDisplay::setScreenWindow(Sc
     // disconnect existing screen window if any
     if ( _screenWindow )
     {
-        disconnect( _screenWindow , 0 , this , 0 );
+        disconnect( _screenWindow , nullptr , this , nullptr );
     }
 
     _screenWindow = window;
@@ -194,10 +194,12 @@ void TerminalDisplay::setColorTable(cons
    QCodec.
 */
 
-static inline bool isLineChar(wchar_t c) { return ((c & 0xFF80) == 0x2500);}
-static inline bool isLineCharString(const std::wstring& string)
-{
-        return (string.length() > 0) && (isLineChar(string[0]));
+bool TerminalDisplay::isLineChar(wchar_t c) const {
+    return _drawLineChars && ((c & 0xFF80) == 0x2500);
+}
+
+bool TerminalDisplay::isLineCharString(const std::wstring& string) const {
+    return (string.length() > 0) && (isLineChar(string[0]));
 }
 
 
@@ -262,9 +264,7 @@ void TerminalDisplay::calDrawTextAdditio
 	  _drawTextAdditionHeight = 0;
 	}
 
-	// update the original content
-    _drawTextTestFlag = false;
-	update();
+  _drawTextTestFlag = false;
 }
 
 void TerminalDisplay::setVTFont(const QFont& f)
@@ -312,9 +312,9 @@ void TerminalDisplay::setFont(const QFon
 
 TerminalDisplay::TerminalDisplay(QWidget *parent)
 :QWidget(parent)
-,_screenWindow(0)
+,_screenWindow(nullptr)
 ,_allowBell(true)
-,_gridLayout(0)
+,_gridLayout(nullptr)
 ,_fontHeight(1)
 ,_fontWidth(1)
 ,_fontAscent(1)
@@ -325,7 +325,7 @@ TerminalDisplay::TerminalDisplay(QWidget
 ,_usedColumns(1)
 ,_contentHeight(1)
 ,_contentWidth(1)
-,_image(0)
+,_image(nullptr)
 ,_randomSeed(0)
 ,_resizing(false)
 ,_terminalSizeHint(false)
@@ -349,10 +349,10 @@ TerminalDisplay::TerminalDisplay(QWidget
 ,_tripleClickMode(SelectWholeLine)
 ,_isFixedSize(false)
 ,_possibleTripleClick(false)
-,_resizeWidget(0)
-,_resizeTimer(0)
+,_resizeWidget(nullptr)
+,_resizeTimer(nullptr)
 ,_flowControlWarningEnabled(false)
-,_outputSuspendedLabel(0)
+,_outputSuspendedLabel(nullptr)
 ,_lineSpacing(0)
 ,_colorsInverted(false)
 ,_blendColor(qRgba(0,0,0,0xff))
@@ -361,6 +361,7 @@ TerminalDisplay::TerminalDisplay(QWidget
 ,mMotionAfterPasting(NoMoveScreenWindow)
 ,_leftBaseMargin(1)
 ,_topBaseMargin(1)
+,_drawLineChars(true)
 {
   // variables for draw text
   _drawTextAdditionHeight = 0;
@@ -751,7 +752,7 @@ void TerminalDisplay::drawCursor(QPainte
                                  const QColor& /*backgroundColor*/,
                                  bool& invertCharacterColor)
 {
-    QRect cursorRect = rect;
+    QRectF cursorRect = rect;
     cursorRect.setHeight(_fontHeight - _lineSpacing - 1);
 
     if (!_cursorBlinking)
@@ -765,12 +766,12 @@ void TerminalDisplay::drawCursor(QPainte
        {
             // draw the cursor outline, adjusting the area so that
             // it is draw entirely inside 'rect'
-            int penWidth = qMax(1,painter.pen().width());
+            float penWidth = qMax(1,painter.pen().width());
 
             painter.drawRect(cursorRect.adjusted(penWidth/2,
                                                  penWidth/2,
-                                                 - penWidth/2 - penWidth%2,
-                                                 - penWidth/2 - penWidth%2));
+                                                 - penWidth/2,
+                                                 - penWidth/2));
             if ( hasFocus() )
             {
                 painter.fillRect(cursorRect, _cursorColor.isValid() ? _cursorColor : foregroundColor);
@@ -941,7 +942,7 @@ void TerminalDisplay::scrollImage(int li
 
     // return if there is nothing to do
     if (    lines == 0
-         || _image == 0
+         || _image == nullptr
          || !region.isValid()
          || (region.top() + abs(lines)) >= region.bottom()
          || this->_lines <= region.height() ) return;
@@ -960,8 +961,10 @@ void TerminalDisplay::scrollImage(int li
     // Set the QT_FLUSH_PAINT environment variable to '1' before starting the
     // application to monitor repainting.
     //
-    int scrollBarWidth = _scrollBar->isHidden() ? 0 : _scrollBar->width();
-    const int SCROLLBAR_CONTENT_GAP = 1;
+    int scrollBarWidth = _scrollBar->isHidden() ? 0 :
+                         _scrollBar->style()->styleHint(QStyle::SH_ScrollBar_Transient, nullptr, _scrollBar) ?
+                         0 : _scrollBar->width();
+    const int SCROLLBAR_CONTENT_GAP = scrollBarWidth == 0 ? 0 : 1;
     QRect scrollRect;
     if ( _scrollbarLocation == QTermWidget::ScrollBarLeft )
     {
@@ -1371,18 +1374,16 @@ void TerminalDisplay::paintEvent( QPaint
   {
     calDrawTextAdditionHeight(paint);
   }
-  else
+
+  const auto rects = (pe->region() & contentsRect()).rects();
+  for (const QRect &rect : rects)
   {
-      const auto rects = (pe->region() & contentsRect()).rects();
-      for (const QRect &rect : rects)
-      {
-        drawBackground(paint,rect,palette().background().color(),
-                       true /* use opacity setting */);
-        drawContents(paint, rect);
-      }
-      drawInputMethodPreeditString(paint,preeditRect());
-      paintFilters(paint);
+    drawBackground(paint,rect,palette().background().color(),
+                   true /* use opacity setting */);
+    drawContents(paint, rect);
   }
+  drawInputMethodPreeditString(paint,preeditRect());
+  paintFilters(paint);
 }
 
 QPoint TerminalDisplay::cursorPosition() const
@@ -1390,7 +1391,7 @@ QPoint TerminalDisplay::cursorPosition()
     if (_screenWindow)
         return _screenWindow->cursorPosition();
     else
-        return QPoint(0,0);
+        return {0,0};
 }
 
 QRect TerminalDisplay::preeditRect() const
@@ -1398,7 +1399,7 @@ QRect TerminalDisplay::preeditRect() con
     const int preeditLength = string_width(_inputMethodData.preeditString);
 
     if ( preeditLength == 0 )
-        return QRect();
+        return {};
 
     return QRect(_leftMargin + _fontWidth*cursorPosition().x(),
                  _topMargin + _fontHeight*cursorPosition().y(),
@@ -1560,10 +1561,10 @@ QRect TerminalDisplay::calculateTextArea
   int left = _fixedFont ? _fontWidth * startColumn : textWidth(0, startColumn, line);
   int top = _fontHeight * line;
   int width = _fixedFont ? _fontWidth * length : textWidth(startColumn, length, line);
-  return QRect(_leftMargin + topLeftX + left,
+  return {_leftMargin + topLeftX + left,
                _topMargin + topLeftY + top,
                width,
-               _fontHeight);
+               _fontHeight};
 }
 
 void TerminalDisplay::drawContents(QPainter &paint, const QRect &rect)
@@ -2346,26 +2347,24 @@ void TerminalDisplay::mouseReleaseEvent(
 void TerminalDisplay::getCharacterPosition(const QPoint& widgetPoint,int& line,int& column) const
 {
     line = (widgetPoint.y()-contentsRect().top()-_topMargin) / _fontHeight;
+    if (line < 0)
+        line = 0;
+    if (line >= _usedLines)
+        line = _usedLines - 1;
 
+    int x = widgetPoint.x() + _fontWidth / 2 - contentsRect().left() - _leftMargin;
     if ( _fixedFont )
-        column = (widgetPoint.x() + _fontWidth/2 -contentsRect().left()-_leftMargin) / _fontWidth;
+        column = x / _fontWidth;
     else
     {
-        int x = contentsRect().left() + widgetPoint.x() - _fontWidth/2;
         column = 0;
-
-        while(x > textWidth(0, column, line))
+        while(column + 1 < _usedColumns && x > textWidth(0, column + 1, line))
             column++;
     }
 
-    if ( line < 0 )
-        line = 0;
     if ( column < 0 )
         column = 0;
 
-    if ( line >= _usedLines )
-        line = _usedLines-1;
-
     // the column value returned can be equal to _usedColumns, which
     // is the position just after the last character displayed in a line.
     //
@@ -2681,7 +2680,10 @@ void TerminalDisplay::bracketText(QStrin
 
 void TerminalDisplay::setSelection(const QString& t)
 {
-  QApplication::clipboard()->setText(t, QClipboard::Selection);
+    if (QApplication::clipboard()->supportsSelection())
+    {
+        QApplication::clipboard()->setText(t, QClipboard::Selection);
+    }
 }
 
 void TerminalDisplay::copyClipboard()
diff -pruN 0.14.1-3/lib/TerminalDisplay.h 0.15.0-0ubuntu1/lib/TerminalDisplay.h
--- 0.14.1-3/lib/TerminalDisplay.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/TerminalDisplay.h	2020-04-24 03:22:14.000000000 +0000
@@ -82,8 +82,8 @@ class KONSOLEPRIVATE_EXPORT TerminalDisp
 
 public:
     /** Constructs a new terminal display widget with the specified parent. */
-    TerminalDisplay(QWidget *parent=0);
-    virtual ~TerminalDisplay();
+    TerminalDisplay(QWidget *parent=nullptr);
+    ~TerminalDisplay() override;
 
     /** Returns the terminal color palette used by the display. */
     const ColorEntry* colorTable() const;
@@ -266,7 +266,7 @@ public:
     void setFixedSize(int cols, int lins);
 
     // reimplemented
-    QSize sizeHint() const;
+    QSize sizeHint() const override;
 
     /**
      * Sets which characters, in addition to letters and numbers,
@@ -352,6 +352,12 @@ public:
     static bool antialias()                 { return _antialiasText;   }
 
     /**
+     * Specify whether line chars should be drawn by ourselves or left to
+     * underlying font rendering libraries.
+     */
+    void setDrawLineChars(bool drawLineChars) { _drawLineChars = drawLineChars; }
+
+    /**
      * Specifies whether characters with intense colors should be rendered
      * as bold. Defaults to true.
      */
@@ -556,30 +562,30 @@ signals:
     void usesMouseChanged();
 
 protected:
-    virtual bool event( QEvent * );
+    bool event( QEvent * ) override;
 
-    virtual void paintEvent( QPaintEvent * );
+    void paintEvent( QPaintEvent * ) override;
 
-    virtual void showEvent(QShowEvent*);
-    virtual void hideEvent(QHideEvent*);
-    virtual void resizeEvent(QResizeEvent*);
+    void showEvent(QShowEvent*) override;
+    void hideEvent(QHideEvent*) override;
+    void resizeEvent(QResizeEvent*) override;
 
     virtual void fontChange(const QFont &font);
-    virtual void focusInEvent(QFocusEvent* event);
-    virtual void focusOutEvent(QFocusEvent* event);
-    virtual void keyPressEvent(QKeyEvent* event);
-    virtual void mouseDoubleClickEvent(QMouseEvent* ev);
-    virtual void mousePressEvent( QMouseEvent* );
-    virtual void mouseReleaseEvent( QMouseEvent* );
-    virtual void mouseMoveEvent( QMouseEvent* );
+    void focusInEvent(QFocusEvent* event) override;
+    void focusOutEvent(QFocusEvent* event) override;
+    void keyPressEvent(QKeyEvent* event) override;
+    void mouseDoubleClickEvent(QMouseEvent* ev) override;
+    void mousePressEvent( QMouseEvent* ) override;
+    void mouseReleaseEvent( QMouseEvent* ) override;
+    void mouseMoveEvent( QMouseEvent* ) override;
     virtual void extendSelection( const QPoint& pos );
-    virtual void wheelEvent( QWheelEvent* );
+    void wheelEvent( QWheelEvent* ) override;
 
-    virtual bool focusNextPrevChild( bool next );
+    bool focusNextPrevChild( bool next ) override;
 
     // drag and drop
-    virtual void dragEnterEvent(QDragEnterEvent* event);
-    virtual void dropEvent(QDropEvent* event);
+    void dragEnterEvent(QDragEnterEvent* event) override;
+    void dropEvent(QDropEvent* event) override;
     void doDrag();
     enum DragState { diNone, diPending, diDragging };
 
@@ -602,8 +608,8 @@ protected:
     void mouseTripleClickEvent(QMouseEvent* ev);
 
     // reimplemented
-    virtual void inputMethodEvent ( QInputMethodEvent* event );
-    virtual QVariant inputMethodQuery( Qt::InputMethodQuery query ) const;
+    void inputMethodEvent ( QInputMethodEvent* event ) override;
+    QVariant inputMethodQuery( Qt::InputMethodQuery query ) const override;
 
 protected slots:
 
@@ -697,6 +703,9 @@ private:
 
     bool handleShortcutOverrideEvent(QKeyEvent* event);
 
+    bool isLineChar(wchar_t c) const;
+    bool isLineCharString(const std::wstring& string) const;
+
     // the window onto the terminal screen which this display
     // is currently showing.
     QPointer<ScreenWindow> _screenWindow;
@@ -827,6 +836,8 @@ private:
     int _leftBaseMargin;
     int _topBaseMargin;
 
+    bool _drawLineChars;
+
 public:
     static void setTransparencyEnabled(bool enable)
     {
@@ -841,8 +852,8 @@ Q_OBJECT
 public:
     AutoScrollHandler(QWidget* parent);
 protected:
-    virtual void timerEvent(QTimerEvent* event);
-    virtual bool eventFilter(QObject* watched,QEvent* event);
+    void timerEvent(QTimerEvent* event) override;
+    bool eventFilter(QObject* watched,QEvent* event) override;
 private:
     QWidget* widget() const { return static_cast<QWidget*>(parent()); }
     int _timerId;
diff -pruN 0.14.1-3/lib/tools.cpp 0.15.0-0ubuntu1/lib/tools.cpp
--- 0.14.1-3/lib/tools.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/tools.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -17,7 +17,7 @@ QString get_kb_layout_dir()
     QString k(QLatin1String(KB_LAYOUT_DIR));
     QDir d(k);
 
-    qDebug() << "default KB_LAYOUT_DIR: " << k;
+    //qDebug() << "default KB_LAYOUT_DIR: " << k;
 
     if (d.exists())
     {
@@ -30,12 +30,12 @@ QString get_kb_layout_dir()
     //qDebug() << d.path();
     if (d.exists())
         return QCoreApplication::applicationDirPath() + QLatin1String("/kb-layouts/");
-#ifdef Q_WS_MAC
-    d.setPath(QCoreApplication::applicationDirPath() + "/../Resources/kb-layouts/");
+#ifdef Q_OS_MAC
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/kb-layouts/"));
     if (d.exists())
-        return QCoreApplication::applicationDirPath() + "/../Resources/kb-layouts/";
+        return QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/kb-layouts/");
 #endif
-    qDebug() << "Cannot find KB_LAYOUT_DIR. Default:" << k;
+    //qDebug() << "Cannot find KB_LAYOUT_DIR. Default:" << k;
     return QString();
 }
 
@@ -76,13 +76,13 @@ const QStringList get_color_schemes_dirs
             rval.clear();
         rval << (QCoreApplication::applicationDirPath() + QLatin1String("/color-schemes/"));
     }
-#ifdef Q_WS_MAC
-    d.setPath(QCoreApplication::applicationDirPath() + "/../Resources/color-schemes/");
+#ifdef Q_OS_MAC
+    d.setPath(QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/color-schemes/"));
     if (d.exists())
     {
         if (!rval.isEmpty())
             rval.clear();
-        rval << (QCoreApplication::applicationDirPath() + "/../Resources/color-schemes/");
+        rval << (QCoreApplication::applicationDirPath() + QLatin1String("/../Resources/color-schemes/"));
     }
 #endif
     for (const QString& custom_dir : const_cast<const QStringList&>(custom_color_schemes_dirs))
diff -pruN 0.14.1-3/lib/translations/qtermwidget_arn.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_arn.ts
--- 0.14.1-3/lib/translations/qtermwidget_arn.ts	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_arn.ts	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,125 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="arn">
+<context>
+    <name>Konsole::TerminalDisplay</name>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
+        <source>Size: XXX x XXX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
+        <source>Size: %1 x %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
+        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Konsole::Vt102Emulation</name>
+    <message>
+        <location filename="../Vt102Emulation.cpp" line="1105"/>
+        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../ColorScheme.cpp" line="278"/>
+        <location filename="../ColorScheme.cpp" line="293"/>
+        <source>Un-named Color Scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ColorScheme.cpp" line="464"/>
+        <source>Accessible Color Scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="515"/>
+        <source>Open Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="516"/>
+        <source>Copy Link Address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="520"/>
+        <source>Send Email To...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="521"/>
+        <source>Copy Email Address</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QTermWidget</name>
+    <message>
+        <location filename="../qtermwidget.cpp" line="459"/>
+        <source>Color Scheme Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qtermwidget.cpp" line="460"/>
+        <source>Cannot load color scheme: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SearchBar</name>
+    <message>
+        <location filename="../SearchBar.cpp" line="40"/>
+        <source>Match case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="46"/>
+        <source>Regular expression</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="50"/>
+        <source>Highlight all matches</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="14"/>
+        <source>SearchBar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="20"/>
+        <source>X</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="32"/>
+        <source>Find:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="42"/>
+        <source>&lt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="54"/>
+        <source>&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="66"/>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_ast.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_ast.ts
--- 0.14.1-3/lib/translations/qtermwidget_ast.ts	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_ast.ts	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,125 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="ast">
+<context>
+    <name>Konsole::TerminalDisplay</name>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
+        <source>Size: XXX x XXX</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
+        <source>Size: %1 x %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
+        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Konsole::Vt102Emulation</name>
+    <message>
+        <location filename="../Vt102Emulation.cpp" line="1105"/>
+        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../ColorScheme.cpp" line="278"/>
+        <location filename="../ColorScheme.cpp" line="293"/>
+        <source>Un-named Color Scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ColorScheme.cpp" line="464"/>
+        <source>Accessible Color Scheme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="515"/>
+        <source>Open Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="516"/>
+        <source>Copy Link Address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="520"/>
+        <source>Send Email To...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="521"/>
+        <source>Copy Email Address</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QTermWidget</name>
+    <message>
+        <location filename="../qtermwidget.cpp" line="459"/>
+        <source>Color Scheme Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../qtermwidget.cpp" line="460"/>
+        <source>Cannot load color scheme: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SearchBar</name>
+    <message>
+        <location filename="../SearchBar.cpp" line="40"/>
+        <source>Match case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="46"/>
+        <source>Regular expression</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="50"/>
+        <source>Highlight all matches</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="14"/>
+        <source>SearchBar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="20"/>
+        <source>X</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="32"/>
+        <source>Find:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="42"/>
+        <source>&lt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="54"/>
+        <source>&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="66"/>
+        <source>...</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_ca.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_ca.ts
--- 0.14.1-3/lib/translations/qtermwidget_ca.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_ca.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Mida: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Mida: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;La sortida ha estat &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspesa&lt;/a&gt; en prémer Ctrl+S.  Premeu &lt;b&gt;Ctrl+Q&lt;/b&gt; per reprendre-la.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Esquema de color accessible</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Obre l&apos;enllaç</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Copia l&apos;adreça de l&apos;enllaç</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Envia un correu electrònic a...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Copia l&apos;adreça de correu electrònic</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Error de l&apos;esquema de color</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>No es pot carregar l&apos;esquema de color: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_cs.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_cs.ts
--- 0.14.1-3/lib/translations/qtermwidget_cs.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_cs.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,19 +4,19 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Velikost: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Velikost: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
-        <translation>&lt;qt&gt;Výstup byl &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;pozastaven&lt;/a&gt; stisknutím Ctrl+S.  Znovu ho spustíte stisknutím &lt;b&gt;Ctrl+Q&lt;/b&gt;.&lt;/qt&gt;</translation>
+        <translation>&lt;qt&gt;Výstup byl &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;pozastaven&lt;/a&gt; stisknutím Ctrl+S. Znovu ho spustíte stisknutím &lt;b&gt;Ctrl+Q&lt;/b&gt;.&lt;/qt&gt;</translation>
     </message>
 </context>
 <context>
@@ -24,7 +24,7 @@
     <message>
         <location filename="../Vt102Emulation.cpp" line="1105"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
-        <translation>Není k dispozici žádný překladač klávesnice. Chybí informace pro převod kódů stisknutých kláves na znaky posílané na terminál.</translation>
+        <translation>Není k dispozici žádný překladač klávesnice. Chybí tak informace pro převod kódů stisknutých kláves na znaky posílané na terminál.</translation>
     </message>
 </context>
 <context>
@@ -38,25 +38,25 @@
     <message>
         <location filename="../ColorScheme.cpp" line="464"/>
         <source>Accessible Color Scheme</source>
-        <translation>Barevné schéma pro zrakově hendikepované uživatele</translation>
+        <translation>Barevné schéma pro uživatele se zrakovou vadou</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Otevřít odkaz</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Zkopírovat adresu odkazu</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Poslat e-mail na…</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Zkopírovat e-mailovou adresu</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Chyba barevného schématu</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Nedaří se načíst barevné schéma: %1</translation>
     </message>
@@ -94,7 +94,7 @@
     <message>
         <location filename="../SearchBar.ui" line="14"/>
         <source>SearchBar</source>
-        <translation>Pruh hledání</translation>
+        <translation>Lišta hledání</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="20"/>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_cy.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_cy.ts
--- 0.14.1-3/lib/translations/qtermwidget_cy.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_cy.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation></translation>
     </message>
@@ -41,22 +41,22 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation></translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation></translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_da.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_da.ts
--- 0.14.1-3/lib/translations/qtermwidget_da.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_da.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Størrelse: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Størrelse: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Output er blevet &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspenderet&lt;/a&gt; ved tryk på Ctrl+S. Tryk på &lt;b&gt;Ctrl+Q&lt;/b&gt; for at genoptage.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Tilgængeligt farveskema</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Åbn link</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Kopiér linkadresse</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Send e-mail til...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Kopiér e-mailadresse</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Fejl ved farveskema</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Kan ikke indlæse farveskema: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_de.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_de.ts
--- 0.14.1-3/lib/translations/qtermwidget_de.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_de.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,19 +4,19 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Größe: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Größe: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
-        <translation>&lt;qt&gt;Ausgabe wurde &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ausgesetzt&lt;/a&gt; beim Drücken von Strg+S.  Drücke &lt;b&gt;Strg+Q&lt;/b&gt; um fortzufahren.&lt;/qt&gt;</translation>
+        <translation>&lt;qt&gt;Druch drücken von Strg+S wurde die Ausgabe &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;unterbrochen&lt;/a&gt;.  &lt;b&gt;Strg+Q&lt;/b&gt; drücken um fortzufahren.&lt;/qt&gt;</translation>
     </message>
 </context>
 <context>
@@ -24,7 +24,7 @@
     <message>
         <location filename="../Vt102Emulation.cpp" line="1105"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
-        <translation>Kein Tastaturinterpretierer verfügbar. Die benötigte Information, um Tastenbefehle in Zeichen umzuwandeln und anschließenfd zum Terminal zu schicken, fehlt.</translation>
+        <translation>Kein Tastaturinterpreter verfügbar. Die benötigte Information, um Tastenbefehle in Zeichen umzuwandeln und anschließenfd zum Terminal zu senden, fehlt.</translation>
     </message>
 </context>
 <context>
@@ -33,7 +33,7 @@
         <location filename="../ColorScheme.cpp" line="278"/>
         <location filename="../ColorScheme.cpp" line="293"/>
         <source>Un-named Color Scheme</source>
-        <translation>Unbenanntes Farbschema</translation>
+        <translation>Nicht benanntes Farbschema</translation>
     </message>
     <message>
         <location filename="../ColorScheme.cpp" line="464"/>
@@ -41,22 +41,22 @@
         <translation>Zugängliches Farbschema</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Link öffnen</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
-        <translation>Linkadresse kopieren</translation>
+        <translation>Link-Adresse kopieren</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>E-Mail senden an...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>E-Mail-Adresse kopieren</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
-        <translation>Farbschemafehler</translation>
+        <translation>Fehler im Farbschema</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Kann Farbschema nicht laden: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_el.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_el.ts
--- 0.14.1-3/lib/translations/qtermwidget_el.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_el.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Μέγεθος: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Μέγεθος: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Η έξοδος έχει &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;ανασταλεί&lt;/a&gt; με τον συνδυασμό πλήκτρων Ctrl+S. Πιέστε &lt;b&gt;Ctrl+Q&lt;/b&gt; για επαναφορά.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Προσπελάσιμος χρωματικός σχηματισμός</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Άνοιγμα του δεσμού</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Αντιγραφή διεύθυνσης του δεσμού</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Αποστολή ηλ. αλληλογραφίας προς...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Αντιγραφή της ηλ. διεύθυνσης</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Σφάλμα του χρωματικού συνδυασμού</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Αδύνατη η φόρτωση του χρωματικού συνδυασμού: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_es.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_es.ts
--- 0.14.1-3/lib/translations/qtermwidget_es.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_es.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Tamaño: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Tamaño: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;La salida ha sido &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspendida&lt;/a&gt; al pulsar Ctrl+S.  Pulse &lt;b&gt;Ctrl+Q&lt;/b&gt; para reanudarla.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Esquema de color accesible</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Abrir el enlace</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Copiar la dirección del enlace</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Enviar correo a...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Copiar la dirección de correo</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Error del esquema de color</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>No se puede cargar el esquema de color: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_fr.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_fr.ts
--- 0.14.1-3/lib/translations/qtermwidget_fr.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_fr.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,19 +4,19 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Taille : XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Taille : %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
-        <translation>&lt;qt&gt;La sortie a été &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspendue&lt;/a&gt; en pressant Ctrl+S.  Pressez &lt;b&gt;Ctrl+Q&lt;/b&gt; pour reprendre.&lt;/qt&gt;</translation>
+        <translation>&lt;qt&gt;La sortie a été &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspendue&lt;/a&gt; en pressant Ctrl+S.  Presser &lt;b&gt;Ctrl+Q&lt;/b&gt; pour reprendre.&lt;/qt&gt;</translation>
     </message>
 </context>
 <context>
@@ -24,7 +24,7 @@
     <message>
         <location filename="../Vt102Emulation.cpp" line="1105"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
-        <translation>Aucun traducteur disponible.  L&apos;information nécessaire à la conversion des touches pressées en caractères à envoyer au terminal est absente.</translation>
+        <translation>Aucun traducteur de clavier disponible. Les informations nécessaires pour convertir les touches utilisées en caractères à envoyer au terminal sont manquantes.</translation>
     </message>
 </context>
 <context>
@@ -33,30 +33,30 @@
         <location filename="../ColorScheme.cpp" line="278"/>
         <location filename="../ColorScheme.cpp" line="293"/>
         <source>Un-named Color Scheme</source>
-        <translation>Schéma des couleurs non nommé</translation>
+        <translation>Jeu de couleurs non nommé</translation>
     </message>
     <message>
         <location filename="../ColorScheme.cpp" line="464"/>
         <source>Accessible Color Scheme</source>
-        <translation>Schéma des couleur accessible</translation>
+        <translation>Schéma de couleur accessible</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Ouvrir le lien</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Copier l&apos;adresse du lien</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
-        <translation>Envoyer un courriel à ...</translation>
+        <translation>Envoyer un courriel à...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Copier l&apos;adresse du courriel</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Erreur du schéma des couleurs</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Impossible de charger le schéma de couleurs : %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_gl.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_gl.ts
--- 0.14.1-3/lib/translations/qtermwidget_gl.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_gl.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Tamaño: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Tamaño: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;A saída foi &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspendida&lt;/a&gt; ao premer Ctrl+S.  Prema &lt;b&gt;Ctrl+Q&lt;/b&gt; para continuar.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Esquema de cor accesíbel</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Abrir a ligazón</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Copiar o enderezo da ligazón</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Enviar correo a...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Copiar o enderezo de correo</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Produciuse un erro no esquema de cor</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Non é posíbel cargar o esquema de cor: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_he.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_he.ts
--- 0.14.1-3/lib/translations/qtermwidget_he.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_he.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>גודל: XXX × XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>גודל: %1 × %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;הפלט &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;הושהה&lt;/a&gt; בלחיצה על Ctrl+S.  יש ללחוץ על &lt;b&gt;Ctrl+Q&lt;/b&gt; כדי להמשיך.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>ערכת צבעים נגישה</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>פתיחת קישור</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>העתקת כתובת קישור</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>שליחת דוא״ל אל…</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>העתקת כתובת דוא״ל</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>שגיאת ערכת צבעים</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>לא ניתן לטעון ערכת צבעים: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_hu.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_hu.ts
--- 0.14.1-3/lib/translations/qtermwidget_hu.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_hu.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Méret: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Méret: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;A kimenet &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;el van nyomva&lt;/a&gt; a Ctrl+S megnyomásával.  Nyomj &lt;b&gt;Ctrl+Q -t&lt;/b&gt; a visszatéréshez.&lt;/qt&gt;</translation>
     </message>
@@ -41,35 +41,35 @@
         <translation>Elérhető színséma</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Link megnyitás</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Link cím másolás</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
-        <translation>Email küldés ...</translation>
+        <translation>Email küldése ...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
-        <translation>Email cím másolás</translation>
+        <translation>Email cím másolása</translation>
     </message>
 </context>
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Színséma hiba</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>A %1 színséma elérhetetlen</translation>
     </message>
@@ -84,7 +84,7 @@
     <message>
         <location filename="../SearchBar.cpp" line="46"/>
         <source>Regular expression</source>
-        <translation>Szaabályos kifejezés</translation>
+        <translation>Szabályos kifejezés</translation>
     </message>
     <message>
         <location filename="../SearchBar.cpp" line="50"/>
@@ -104,7 +104,7 @@
     <message>
         <location filename="../SearchBar.ui" line="32"/>
         <source>Find:</source>
-        <translation>Keres:</translation>
+        <translation>Keresés:</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="42"/>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_ja.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_ja.ts
--- 0.14.1-3/lib/translations/qtermwidget_ja.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_ja.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,19 +4,19 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
-        <translation type="unfinished"></translation>
+        <translation>サイズ: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
-        <translation type="unfinished"></translation>
+        <translation>サイズ: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;qt&gt;Ctrl+S を押して出力を&lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;中断&lt;/a&gt; しました 。再開するには &lt;b&gt;Ctrl+Q&lt;/b&gt; を押します。&lt;/qt&gt;</translation>
     </message>
 </context>
 <context>
@@ -24,7 +24,7 @@
     <message>
         <location filename="../Vt102Emulation.cpp" line="1105"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
-        <translation type="unfinished"></translation>
+        <translation>キーボードトランスレータがありません。押されたキーを文字に変換してターミナルへ送信するために必要な情報がありません。</translation>
     </message>
 </context>
 <context>
@@ -33,30 +33,30 @@
         <location filename="../ColorScheme.cpp" line="278"/>
         <location filename="../ColorScheme.cpp" line="293"/>
         <source>Un-named Color Scheme</source>
-        <translation>名前のないカラースキーム</translation>
+        <translation>名前のない配色</translation>
     </message>
     <message>
         <location filename="../ColorScheme.cpp" line="464"/>
         <source>Accessible Color Scheme</source>
-        <translation>アクセス可能なカラースキーム</translation>
+        <translation>アクセス可能な配色</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>リンクを開く</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>リンクのアドレスをコピー</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>メールを送信...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>メールアドレスをコピー</translation>
     </message>
@@ -64,14 +64,14 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
-        <translation>カラースキームのエラー</translation>
+        <translation>配色のエラー</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
-        <translation>カラースキームをロードすることができません: %1</translation>
+        <translation>配色をロードできません: %1</translation>
     </message>
 </context>
 <context>
@@ -79,7 +79,7 @@
     <message>
         <location filename="../SearchBar.cpp" line="40"/>
         <source>Match case</source>
-        <translation type="unfinished"></translation>
+        <translation>大文字と小文字の区別</translation>
     </message>
     <message>
         <location filename="../SearchBar.cpp" line="46"/>
@@ -89,7 +89,7 @@
     <message>
         <location filename="../SearchBar.cpp" line="50"/>
         <source>Highlight all matches</source>
-        <translation>一致するものをハイライト</translation>
+        <translation>一致する全ての文字列を強調表示</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="14"/>
@@ -104,22 +104,22 @@
     <message>
         <location filename="../SearchBar.ui" line="32"/>
         <source>Find:</source>
-        <translation>探す:</translation>
+        <translation>検索:</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="42"/>
         <source>&lt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="54"/>
         <source>&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&gt;</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="66"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>...</translation>
     </message>
 </context>
 </TS>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_lt.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_lt.ts
--- 0.14.1-3/lib/translations/qtermwidget_lt.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_lt.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Dydis: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Dydis: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Išvestis buvo &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;pristabdyta,&lt;/a&gt; paspaudžiant Ctrl(Vald)+S.  Paspauskite &lt;b&gt;Ctrl(Vald)+Q&lt;/b&gt;, norėdami pratęsti.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Pasiekiamas spalvų rinkinys</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Atverti nuorodą</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Kopijuoti nuorodos adresą</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Siųsti el. paštą...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Kopijuoti el. pašto adresą</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Spalvų rinkinio klaida</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Nepavyksta įkelti spalvų rinkinio: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_nb_NO.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_nb_NO.ts
--- 0.14.1-3/lib/translations/qtermwidget_nb_NO.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_nb_NO.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Størrelse: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Størrelse: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Utgangssignalet ble &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;stoppet&lt;/a&gt; da Ctrl+S ble trykket.  Trykk &lt;b&gt;Ctrl+Q&lt;/b&gt; for å fortsette.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Fargemønster for funksjonshemmede</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Åpne lenke</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Kopier lenkeadresse</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Send epost til...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Kopier epostadressen</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Feil med fargemønster</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Kan ikke åpne fargemønster: %1</translation>
     </message>
@@ -94,7 +94,7 @@
     <message>
         <location filename="../SearchBar.ui" line="14"/>
         <source>SearchBar</source>
-        <translation>Søkefelt</translation>
+        <translation>Søkelinje</translation>
     </message>
     <message>
         <location filename="../SearchBar.ui" line="20"/>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_pl.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_pl.ts
--- 0.14.1-3/lib/translations/qtermwidget_pl.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_pl.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Rozmiar: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Rozmiar: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Wyjście zostało &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;wstrzymane&lt;/a&gt; skrótem Ctrl+S. Wciśnij &lt;b&gt;Ctrl+Q&lt;/b&gt; aby wznowić.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Paleta o zwiększonej przystępności</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Przejdź pod adres</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Kopiuj adres łącza</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Wyślij e-mail do…</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Kopiuj adres e-mail</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Błąd w palecie</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Nie można wczytać palety: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_pt_BR.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_pt_BR.ts
--- 0.14.1-3/lib/translations/qtermwidget_pt_BR.ts	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_pt_BR.ts	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,125 @@
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pt_BR">
+<context>
+    <name>Konsole::TerminalDisplay</name>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
+        <source>Size: XXX x XXX</source>
+        <translation>Tamanho: XXX x XXX</translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
+        <source>Size: %1 x %2</source>
+        <translation>Tamanho: %1 x %2</translation>
+    </message>
+    <message>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
+        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
+        <translation>&lt;qt&gt;A saída foi &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspensa&lt;/a&gt; pressionando Ctrl+S.  Pressione &lt;b&gt;Ctrl+Q&lt;/b&gt; para continuar.&lt;/qt&gt;</translation>
+    </message>
+</context>
+<context>
+    <name>Konsole::Vt102Emulation</name>
+    <message>
+        <location filename="../Vt102Emulation.cpp" line="1105"/>
+        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
+        <translation>Nenhum tradutor de teclado disponível.  A informação necessária para converter a tecla pressionada em caracteres para enviar para o terminal está faltando.</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../ColorScheme.cpp" line="278"/>
+        <location filename="../ColorScheme.cpp" line="293"/>
+        <source>Un-named Color Scheme</source>
+        <translation>Esquema de cor sem nome</translation>
+    </message>
+    <message>
+        <location filename="../ColorScheme.cpp" line="464"/>
+        <source>Accessible Color Scheme</source>
+        <translation>Esquema de cor acessível</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="515"/>
+        <source>Open Link</source>
+        <translation>Abrir Link</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="516"/>
+        <source>Copy Link Address</source>
+        <translation>Copiar Endereço do Link</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="520"/>
+        <source>Send Email To...</source>
+        <translation>Enviar E-mail Para...</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="521"/>
+        <source>Copy Email Address</source>
+        <translation>Copiar Endereço de E-mail</translation>
+    </message>
+</context>
+<context>
+    <name>QTermWidget</name>
+    <message>
+        <location filename="../qtermwidget.cpp" line="459"/>
+        <source>Color Scheme Error</source>
+        <translation>Erro no esquema de cor</translation>
+    </message>
+    <message>
+        <location filename="../qtermwidget.cpp" line="460"/>
+        <source>Cannot load color scheme: %1</source>
+        <translation>Não foi possível carregar o esquema de cor: %1</translation>
+    </message>
+</context>
+<context>
+    <name>SearchBar</name>
+    <message>
+        <location filename="../SearchBar.cpp" line="40"/>
+        <source>Match case</source>
+        <translation>Caso de compatibilidade</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="46"/>
+        <source>Regular expression</source>
+        <translation>Expressão Regular</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.cpp" line="50"/>
+        <source>Highlight all matches</source>
+        <translation>Destacar todas as correspondências</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="14"/>
+        <source>SearchBar</source>
+        <translation>Barra de Pesquisa</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="20"/>
+        <source>X</source>
+        <translation>X</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="32"/>
+        <source>Find:</source>
+        <translation>Encontrar:</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="42"/>
+        <source>&lt;</source>
+        <translation>&lt;</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="54"/>
+        <source>&gt;</source>
+        <translation>&gt;</translation>
+    </message>
+    <message>
+        <location filename="../SearchBar.ui" line="66"/>
+        <source>...</source>
+        <translation>...</translation>
+    </message>
+</context>
+</TS>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_pt.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_pt.ts
--- 0.14.1-3/lib/translations/qtermwidget_pt.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_pt.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Tamanho: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Tamanho: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;A saída foi &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt; suspendida&lt;/a&gt; com Ctrl+S. Prima &lt;b&gt;Ctrl+Q&lt;/b&gt; para continuar.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Esquema de cores acessível</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Abrir ligação</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Copiar endereço da ligação</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>Enviar e-mail para...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>Copiar endereço de e-mail</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Erro no esquema de cores</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Não foi possível carregar o esquema de cores: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_tr.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_tr.ts
--- 0.14.1-3/lib/translations/qtermwidget_tr.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_tr.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>Boyut: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>Boyut: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Çıktı &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; Ctrl+S basınız. &lt;b&gt;Ctrl+Q&lt;/b&gt; bas devam etmek için.&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>Erişilebilir Renk Şeması</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>Bağlantıyı Aç</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>Bağlantı Adresini Kopyala</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>E-posta gönder...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>E-posta Adresini Kopyala</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>Renk Şema Hatası</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Renk şeması yüklenemedi: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget.ts
--- 0.14.1-3/lib/translations/qtermwidget.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation type="unfinished"></translation>
     </message>
@@ -41,22 +41,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation type="unfinished"></translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation type="unfinished"></translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_zh_CN.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_zh_CN.ts
--- 0.14.1-3/lib/translations/qtermwidget_zh_CN.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_zh_CN.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>大小: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>大小: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;输出已被 Ctrl+S &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;暂停&lt;/a&gt;。按 &lt;b&gt;Ctrl+Q&lt;/b&gt; 复原。&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>可用配色</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>打开链接</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>复制链接地址</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>发送邮件至...</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>复制邮件地址</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>配色错误</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>无法加载配色: %1</translation>
     </message>
diff -pruN 0.14.1-3/lib/translations/qtermwidget_zh_TW.ts 0.15.0-0ubuntu1/lib/translations/qtermwidget_zh_TW.ts
--- 0.14.1-3/lib/translations/qtermwidget_zh_TW.ts	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/translations/qtermwidget_zh_TW.ts	2020-04-24 03:22:14.000000000 +0000
@@ -4,17 +4,17 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1279"/>
+        <location filename="../TerminalDisplay.cpp" line="1282"/>
         <source>Size: XXX x XXX</source>
         <translation>大小：XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1291"/>
+        <location filename="../TerminalDisplay.cpp" line="1294"/>
         <source>Size: %1 x %2</source>
         <translation>大小：%1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3178"/>
+        <location filename="../TerminalDisplay.cpp" line="3180"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;輸出已被Ctrl+S&lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;暫停&lt;/a&gt;。按&lt;b&gt;Ctrl+Q&lt;/b&gt;復原。&lt;/qt&gt;</translation>
     </message>
@@ -41,22 +41,22 @@
         <translation>可用的配色</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="538"/>
+        <location filename="../Filter.cpp" line="515"/>
         <source>Open Link</source>
         <translation>開啟連結</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="539"/>
+        <location filename="../Filter.cpp" line="516"/>
         <source>Copy Link Address</source>
         <translation>複製網址</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="543"/>
+        <location filename="../Filter.cpp" line="520"/>
         <source>Send Email To...</source>
         <translation>傳送郵件給…</translation>
     </message>
     <message>
-        <location filename="../Filter.cpp" line="544"/>
+        <location filename="../Filter.cpp" line="521"/>
         <source>Copy Email Address</source>
         <translation>複製信箱地址</translation>
     </message>
@@ -64,12 +64,12 @@
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="451"/>
+        <location filename="../qtermwidget.cpp" line="459"/>
         <source>Color Scheme Error</source>
         <translation>配色錯誤</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="452"/>
+        <location filename="../qtermwidget.cpp" line="460"/>
         <source>Cannot load color scheme: %1</source>
         <translation>無法載入配色：%1</translation>
     </message>
diff -pruN 0.14.1-3/lib/Vt102Emulation.cpp 0.15.0-0ubuntu1/lib/Vt102Emulation.cpp
--- 0.14.1-3/lib/Vt102Emulation.cpp	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Vt102Emulation.cpp	2020-04-24 03:22:14.000000000 +0000
@@ -38,7 +38,7 @@
 #endif
 
 // Standard
-#include <stdio.h>
+#include <cstdio>
 #include <unistd.h>
 
 // Qt
@@ -343,7 +343,7 @@ void Vt102Emulation::receiveChar(wchar_t
 
     if (epe(   )) { processToken( TY_CSI_PE(cc), 0, 0); resetTokenizer(); return; }
     if (ees(DIG)) { addDigit(cc-'0'); return; }
-    if (eec(';')) { addArgument();    return; }
+    if (eec(';') || eec(':')) { addArgument(); return; }
     for (int i=0;i<=argc;i++)
     {
         if (epp())
@@ -413,10 +413,10 @@ void Vt102Emulation::processWindowAttrib
     return;
   }
 
-  QString newValue;
-  newValue.reserve(tokenBufferPos-i-2);
-  for (int j = 0; j < tokenBufferPos-i-2; j++)
-    newValue[j] = tokenBuffer[i+1+j];
+  // copy from the first char after ';', and skipping the ending delimiter
+  // 0x07 or 0x92. Note that as control characters in OSC text parts are
+  // ignored, only the second char in ST ("\e\\") is appended to tokenBuffer.
+  QString newValue = QString::fromWCharArray(tokenBuffer + i + 1, tokenBufferPos-i-2);
 
   _pendingTitleUpdates[attributeToChange] = newValue;
   _titleUpdateTimer->start(20);
@@ -870,8 +870,12 @@ void Vt102Emulation::sendString(const ch
 
 void Vt102Emulation::reportCursorPosition()
 {
-  char tmp[20];
-  sprintf(tmp,"\033[%d;%dR",_currentScreen->getCursorY()+1,_currentScreen->getCursorX()+1);
+  const size_t sz = 20;
+  char tmp[sz];
+  const size_t r = snprintf(tmp, sz, "\033[%d;%dR",_currentScreen->getCursorY()+1,_currentScreen->getCursorX()+1);
+  if (sz <= r) {
+    qWarning("Vt102Emulation::reportCursorPosition: Buffer too small\n");
+  }
   sendString(tmp);
 }
 
@@ -901,8 +905,12 @@ void Vt102Emulation::reportSecondaryAttr
 void Vt102Emulation::reportTerminalParms(int p)
 // DECREPTPARM
 {
-  char tmp[100];
-  sprintf(tmp,"\033[%d;1;1;112;112;1;0x",p); // not really true.
+  const size_t sz = 100;
+  char tmp[sz];
+  const size_t r = snprintf(tmp, sz, "\033[%d;1;1;112;112;1;0x",p); // not really true.
+  if (sz <= r) {
+    qWarning("Vt102Emulation::reportTerminalParms: Buffer too small\n");
+  }
   sendString(tmp);
 }
 
@@ -1025,7 +1033,7 @@ void Vt102Emulation::sendKeyEvent( QKeyE
         states |= KeyboardTranslator::ApplicationKeypadState;
 
     // check flow control state
-    if (modifiers & Qt::ControlModifier)
+    if (modifiers & KeyboardTranslator::CTRL_MOD)
     {
         switch (event->key()) {
         case Qt::Key_S:
@@ -1080,7 +1088,7 @@ void Vt102Emulation::sendKeyEvent( QKeyE
         {
             textToSend += _codec->fromUnicode(QString::fromUtf8(entry.text(true,modifiers)));
         }
-        else if((modifiers & Qt::ControlModifier) && event->key() >= 0x40 && event->key() < 0x5f) {
+        else if((modifiers & KeyboardTranslator::CTRL_MOD) && event->key() >= 0x40 && event->key() < 0x5f) {
             textToSend += (event->key() & 0x1f);
         }
         else if(event->key() == Qt::Key_Tab) {
@@ -1341,8 +1349,8 @@ char Vt102Emulation::eraseChar() const
 {
   KeyboardTranslator::Entry entry = _keyTranslator->findEntry(
                                             Qt::Key_Backspace,
-                                            0,
-                                            0);
+                                            nullptr,
+                                            nullptr);
   if ( entry.text().count() > 0 )
       return entry.text().at(0);
   else
diff -pruN 0.14.1-3/lib/Vt102Emulation.h 0.15.0-0ubuntu1/lib/Vt102Emulation.h
--- 0.14.1-3/lib/Vt102Emulation.h	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/lib/Vt102Emulation.h	2020-04-24 03:22:14.000000000 +0000
@@ -24,7 +24,7 @@
 #define VT102EMULATION_H
 
 // Standard Library
-#include <stdio.h>
+#include <cstdio>
 
 // Qt
 #include <QKeyEvent>
@@ -82,27 +82,27 @@ Q_OBJECT
 public:
   /** Constructs a new emulation */
   Vt102Emulation();
-  ~Vt102Emulation();
+  ~Vt102Emulation() override;
 
   // reimplemented from Emulation
-  virtual void clearEntireScreen();
-  virtual void reset();
-  virtual char eraseChar() const;
+  void clearEntireScreen() override;
+  void reset() override;
+  char eraseChar() const override;
 
 public slots:
   // reimplemented from Emulation
-  virtual void sendString(const char*,int length = -1);
-  virtual void sendText(const QString& text);
-  virtual void sendKeyEvent(QKeyEvent*);
-  virtual void sendMouseEvent(int buttons, int column, int line, int eventType);
+  void sendString(const char*,int length = -1) override;
+  void sendText(const QString& text) override;
+  void sendKeyEvent(QKeyEvent*) override;
+  void sendMouseEvent(int buttons, int column, int line, int eventType) override;
   virtual void focusLost();
   virtual void focusGained();
 
 protected:
   // reimplemented from Emulation
-  virtual void setMode(int mode);
-  virtual void resetMode(int mode);
-  virtual void receiveChar(wchar_t cc);
+  void setMode(int mode) override;
+  void resetMode(int mode) override;
+  void receiveChar(wchar_t cc) override;
 
 private slots:
   //causes changeTitle() to be emitted for each (int,QString) pair in pendingTitleUpdates
diff -pruN 0.14.1-3/pyqt/cmake/FindPyQt5.cmake 0.15.0-0ubuntu1/pyqt/cmake/FindPyQt5.cmake
--- 0.14.1-3/pyqt/cmake/FindPyQt5.cmake	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/pyqt/cmake/FindPyQt5.cmake	2020-04-24 03:22:14.000000000 +0000
@@ -36,6 +36,7 @@ ELSE(EXISTS PYQT5_VERSION)
     STRING(REGEX REPLACE ".*\npyqt_version_tag:([^\n]+).*$" "\\1" PYQT5_VERSION_TAG ${pyqt5_config})
     STRING(REGEX REPLACE ".*\npyqt_sip_dir:([^\n]+).*$" "\\1" PYQT5_SIP_DIR ${pyqt5_config})
     STRING(REGEX REPLACE ".*\npyqt_sip_flags:([^\n]+).*$" "\\1" PYQT5_SIP_FLAGS ${pyqt5_config})
+    SEPARATE_ARGUMENTS(PYQT5_SIP_FLAGS)
 
     SET(PYQT5_FOUND TRUE)
   ENDIF(pyqt5_config)
diff -pruN 0.14.1-3/pyqt/cmake/FindPyQt5.py 0.15.0-0ubuntu1/pyqt/cmake/FindPyQt5.py
--- 0.14.1-3/pyqt/cmake/FindPyQt5.py	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/pyqt/cmake/FindPyQt5.py	2020-04-24 03:22:14.000000000 +0000
@@ -5,6 +5,7 @@
 import PyQt5.Qt
 import sys
 import os.path
+import site
 
 print("pyqt_version:%06.0x" % PyQt5.Qt.PYQT_VERSION)
 print("pyqt_version_str:%s" % PyQt5.Qt.PYQT_VERSION_STR)
@@ -21,8 +22,18 @@ for item in PyQt5.Qt.PYQT_CONFIGURATION[
         in_t = False
 print("pyqt_version_tag:%s" % pyqt_version_tag)
 
-# FIXME This next line is just a little bit too crude.
-pyqt_sip_dir = os.path.join(sys.prefix, "share", "sip", "PyQt5")
+# FIXME Is there a way to query the path from sip instead of hardcoding it?
+candidates = [
+    os.path.join(site.getsitepackages()[0], "PyQt5", "bindings"),   # sip 5.x
+    os.path.join(sys.prefix, "share", "sip", "PyQt5"),              # sip 4.x
+]
+try:
+    pyqt_sip_dir = next(
+        p for p in candidates
+        if os.path.exists(os.path.join(p, "QtCore", "QtCoremod.sip"))
+    )
+except StopIteration:
+    raise RuntimeError("Cannot find QtCore/QtCoremod.sip from candidates: " + repr(candidates))
 print("pyqt_sip_dir:%s" % pyqt_sip_dir)
 
 print("pyqt_sip_flags:%s" % PyQt5.Qt.PYQT_CONFIGURATION["sip_flags"])
diff -pruN 0.14.1-3/pyqt/CMakeLists.txt 0.15.0-0ubuntu1/pyqt/CMakeLists.txt
--- 0.14.1-3/pyqt/CMakeLists.txt	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/pyqt/CMakeLists.txt	2020-04-24 03:22:14.000000000 +0000
@@ -1,7 +1,5 @@
 set(CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_CURRENT_SOURCE_DIR}/cmake)
 
-# Match what's used in the main macros
-cmake_policy(SET CMP0002 OLD)
 find_package(PythonLibrary)
 
 include(PythonMacros)
@@ -40,6 +38,8 @@ else (PYTHON_VERSION_MAJOR GREATER 2)
     endif()
 endif ()
 
+set(SIP_EXTRA_OPTIONS ${SIP_EXTRA_OPTIONS} ${PYQT5_SIP_FLAGS})
+
 include_directories(
     "${SIP_INCLUDE_DIR}"
 )
diff -pruN 0.14.1-3/README.md 0.15.0-0ubuntu1/README.md
--- 0.14.1-3/README.md	2019-02-25 22:13:12.000000000 +0000
+++ 0.15.0-0ubuntu1/README.md	2020-04-24 03:22:14.000000000 +0000
@@ -52,7 +52,7 @@ License: public-domain
 
 ### Compiling sources
 
-The only runtime dependency is qtbase ≥ 5.6.
+The only runtime dependency is qtbase ≥ 5.7.1.
 In order to build CMake ≥ 3.0.2 and [lxqt-build-tools](https://github.com/lxqt/lxqt-build-tools/) >= 0.4.0 are needed as well as Git to pull translations and optionally latest VCS checkouts.
 
 Code configuration is handled by CMake. CMake variable `CMAKE_INSTALL_PREFIX` will normally have to be set to `/usr`, depending on the way library paths are dealt with on 64bit systems variables like `CMAKE_INSTALL_LIBDIR` may have to be set as well.
diff -pruN 0.14.1-3/.travis.yml 0.15.0-0ubuntu1/.travis.yml
--- 0.14.1-3/.travis.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.15.0-0ubuntu1/.travis.yml	2020-04-24 03:22:14.000000000 +0000
@@ -0,0 +1,25 @@
+language: cpp
+
+sudo: required
+
+dist: bionic
+
+services:
+  - docker
+
+script:
+  - "curl -s https://raw.githubusercontent.com/mikkeloscar/arch-travis/master/arch-travis.sh | bash"
+
+archlinux:
+  repos:
+    - archlinuxcn=https://cdn.repo.archlinuxcn.org/$arch
+  packages:
+    # See *depends in https://github.com/archlinuxcn/repo/blob/master/archlinuxcn/qtermwidget-git/PKGBUILD
+    - git
+    - cmake
+    - lxqt-build-tools-git
+    - qt5-tools
+    - python-pyqt5
+    - python-sip
+    - sip
+  script: bash ./.ci/build.sh
